//*
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.27.1
// 	protoc        v3.19.4
// source: editlog.proto

package hadoop_hdfs

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type AclEditLogProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src     *string          `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
	Entries []*AclEntryProto `protobuf:"bytes,2,rep,name=entries" json:"entries,omitempty"`
}

func (x *AclEditLogProto) Reset() {
	*x = AclEditLogProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_editlog_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AclEditLogProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AclEditLogProto) ProtoMessage() {}

func (x *AclEditLogProto) ProtoReflect() protoreflect.Message {
	mi := &file_editlog_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AclEditLogProto.ProtoReflect.Descriptor instead.
func (*AclEditLogProto) Descriptor() ([]byte, []int) {
	return file_editlog_proto_rawDescGZIP(), []int{0}
}

func (x *AclEditLogProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

func (x *AclEditLogProto) GetEntries() []*AclEntryProto {
	if x != nil {
		return x.Entries
	}
	return nil
}

type XAttrEditLogProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src    *string       `protobuf:"bytes,1,opt,name=src" json:"src,omitempty"`
	XAttrs []*XAttrProto `protobuf:"bytes,2,rep,name=xAttrs" json:"xAttrs,omitempty"`
}

func (x *XAttrEditLogProto) Reset() {
	*x = XAttrEditLogProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_editlog_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *XAttrEditLogProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*XAttrEditLogProto) ProtoMessage() {}

func (x *XAttrEditLogProto) ProtoReflect() protoreflect.Message {
	mi := &file_editlog_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use XAttrEditLogProto.ProtoReflect.Descriptor instead.
func (*XAttrEditLogProto) Descriptor() ([]byte, []int) {
	return file_editlog_proto_rawDescGZIP(), []int{1}
}

func (x *XAttrEditLogProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

func (x *XAttrEditLogProto) GetXAttrs() []*XAttrProto {
	if x != nil {
		return x.XAttrs
	}
	return nil
}

var File_editlog_proto protoreflect.FileDescriptor

var file_editlog_proto_rawDesc = []byte{
	0x0a, 0x0d, 0x65, 0x64, 0x69, 0x74, 0x6c, 0x6f, 0x67, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12,
	0x0b, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x1a, 0x09, 0x61, 0x63,
	0x6c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x0b, 0x78, 0x61, 0x74, 0x74, 0x72, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x22, 0x59, 0x0a, 0x0f, 0x41, 0x63, 0x6c, 0x45, 0x64, 0x69, 0x74, 0x4c,
	0x6f, 0x67, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01,
	0x20, 0x02, 0x28, 0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x12, 0x34, 0x0a, 0x07, 0x65, 0x6e, 0x74,
	0x72, 0x69, 0x65, 0x73, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x68, 0x61, 0x64,
	0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72,
	0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x07, 0x65, 0x6e, 0x74, 0x72, 0x69, 0x65, 0x73, 0x22,
	0x56, 0x0a, 0x11, 0x58, 0x41, 0x74, 0x74, 0x72, 0x45, 0x64, 0x69, 0x74, 0x4c, 0x6f, 0x67, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x01, 0x28,
	0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x12, 0x2f, 0x0a, 0x06, 0x78, 0x41, 0x74, 0x74, 0x72, 0x73,
	0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x17, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e,
	0x68, 0x64, 0x66, 0x73, 0x2e, 0x58, 0x41, 0x74, 0x74, 0x72, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52,
	0x06, 0x78, 0x41, 0x74, 0x74, 0x72, 0x73, 0x42, 0x75, 0x0a, 0x25, 0x6f, 0x72, 0x67, 0x2e, 0x61,
	0x70, 0x61, 0x63, 0x68, 0x65, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66,
	0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x42, 0x0d, 0x45, 0x64, 0x69, 0x74, 0x4c, 0x6f, 0x67, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x73, 0x5a,
	0x3a, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x63, 0x6f, 0x6c, 0x69,
	0x6e, 0x6d, 0x61, 0x72, 0x63, 0x2f, 0x68, 0x64, 0x66, 0x73, 0x2f, 0x76, 0x32, 0x2f, 0x69, 0x6e,
	0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2f,
	0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x5f, 0x68, 0x64, 0x66, 0x73, 0xa0, 0x01, 0x01,
}

var (
	file_editlog_proto_rawDescOnce sync.Once
	file_editlog_proto_rawDescData = file_editlog_proto_rawDesc
)

func file_editlog_proto_rawDescGZIP() []byte {
	file_editlog_proto_rawDescOnce.Do(func() {
		file_editlog_proto_rawDescData = protoimpl.X.CompressGZIP(file_editlog_proto_rawDescData)
	})
	return file_editlog_proto_rawDescData
}

var file_editlog_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_editlog_proto_goTypes = []interface{}{
	(*AclEditLogProto)(nil),   // 0: hadoop.hdfs.AclEditLogProto
	(*XAttrEditLogProto)(nil), // 1: hadoop.hdfs.XAttrEditLogProto
	(*AclEntryProto)(nil),     // 2: hadoop.hdfs.AclEntryProto
	(*XAttrProto)(nil),        // 3: hadoop.hdfs.XAttrProto
}
var file_editlog_proto_depIdxs = []int32{
	2, // 0: hadoop.hdfs.AclEditLogProto.entries:type_name -> hadoop.hdfs.AclEntryProto
	3, // 1: hadoop.hdfs.XAttrEditLogProto.xAttrs:type_name -> hadoop.hdfs.XAttrProto
	2, // [2:2] is the sub-list for method output_type
	2, // [2:2] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_editlog_proto_init() }
func file_editlog_proto_init() {
	if File_editlog_proto != nil {
		return
	}
	file_acl_proto_init()
	file_xattr_proto_init()
	if !protoimpl.UnsafeEnabled {
		file_editlog_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AclEditLogProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_editlog_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*XAttrEditLogProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_editlog_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_editlog_proto_goTypes,
		DependencyIndexes: file_editlog_proto_depIdxs,
		MessageInfos:      file_editlog_proto_msgTypes,
	}.Build()
	File_editlog_proto = out.File
	file_editlog_proto_rawDesc = nil
	file_editlog_proto_goTypes = nil
	file_editlog_proto_depIdxs = nil
}
