//*
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.27.1
// 	protoc        v3.19.4
// source: erasurecoding.proto

package hadoop_hdfs

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type SetErasureCodingPolicyRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src          *string `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
	EcPolicyName *string `protobuf:"bytes,2,opt,name=ecPolicyName" json:"ecPolicyName,omitempty"`
}

func (x *SetErasureCodingPolicyRequestProto) Reset() {
	*x = SetErasureCodingPolicyRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *SetErasureCodingPolicyRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SetErasureCodingPolicyRequestProto) ProtoMessage() {}

func (x *SetErasureCodingPolicyRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SetErasureCodingPolicyRequestProto.ProtoReflect.Descriptor instead.
func (*SetErasureCodingPolicyRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{0}
}

func (x *SetErasureCodingPolicyRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

func (x *SetErasureCodingPolicyRequestProto) GetEcPolicyName() string {
	if x != nil && x.EcPolicyName != nil {
		return *x.EcPolicyName
	}
	return ""
}

type SetErasureCodingPolicyResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *SetErasureCodingPolicyResponseProto) Reset() {
	*x = SetErasureCodingPolicyResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *SetErasureCodingPolicyResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SetErasureCodingPolicyResponseProto) ProtoMessage() {}

func (x *SetErasureCodingPolicyResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SetErasureCodingPolicyResponseProto.ProtoReflect.Descriptor instead.
func (*SetErasureCodingPolicyResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{1}
}

type GetErasureCodingPoliciesRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *GetErasureCodingPoliciesRequestProto) Reset() {
	*x = GetErasureCodingPoliciesRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetErasureCodingPoliciesRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetErasureCodingPoliciesRequestProto) ProtoMessage() {}

func (x *GetErasureCodingPoliciesRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetErasureCodingPoliciesRequestProto.ProtoReflect.Descriptor instead.
func (*GetErasureCodingPoliciesRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{2}
}

type GetErasureCodingPoliciesResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	EcPolicies []*ErasureCodingPolicyProto `protobuf:"bytes,1,rep,name=ecPolicies" json:"ecPolicies,omitempty"`
}

func (x *GetErasureCodingPoliciesResponseProto) Reset() {
	*x = GetErasureCodingPoliciesResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[3]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetErasureCodingPoliciesResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetErasureCodingPoliciesResponseProto) ProtoMessage() {}

func (x *GetErasureCodingPoliciesResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[3]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetErasureCodingPoliciesResponseProto.ProtoReflect.Descriptor instead.
func (*GetErasureCodingPoliciesResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{3}
}

func (x *GetErasureCodingPoliciesResponseProto) GetEcPolicies() []*ErasureCodingPolicyProto {
	if x != nil {
		return x.EcPolicies
	}
	return nil
}

type GetErasureCodingCodecsRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *GetErasureCodingCodecsRequestProto) Reset() {
	*x = GetErasureCodingCodecsRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[4]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetErasureCodingCodecsRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetErasureCodingCodecsRequestProto) ProtoMessage() {}

func (x *GetErasureCodingCodecsRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[4]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetErasureCodingCodecsRequestProto.ProtoReflect.Descriptor instead.
func (*GetErasureCodingCodecsRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{4}
}

type GetErasureCodingCodecsResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Codec []*CodecProto `protobuf:"bytes,1,rep,name=codec" json:"codec,omitempty"`
}

func (x *GetErasureCodingCodecsResponseProto) Reset() {
	*x = GetErasureCodingCodecsResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[5]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetErasureCodingCodecsResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetErasureCodingCodecsResponseProto) ProtoMessage() {}

func (x *GetErasureCodingCodecsResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[5]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetErasureCodingCodecsResponseProto.ProtoReflect.Descriptor instead.
func (*GetErasureCodingCodecsResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{5}
}

func (x *GetErasureCodingCodecsResponseProto) GetCodec() []*CodecProto {
	if x != nil {
		return x.Codec
	}
	return nil
}

type GetErasureCodingPolicyRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src *string `protobuf:"bytes,1,req,name=src" json:"src,omitempty"` // path to get the policy info
}

func (x *GetErasureCodingPolicyRequestProto) Reset() {
	*x = GetErasureCodingPolicyRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[6]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetErasureCodingPolicyRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetErasureCodingPolicyRequestProto) ProtoMessage() {}

func (x *GetErasureCodingPolicyRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[6]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetErasureCodingPolicyRequestProto.ProtoReflect.Descriptor instead.
func (*GetErasureCodingPolicyRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{6}
}

func (x *GetErasureCodingPolicyRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

type GetErasureCodingPolicyResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	EcPolicy *ErasureCodingPolicyProto `protobuf:"bytes,1,opt,name=ecPolicy" json:"ecPolicy,omitempty"`
}

func (x *GetErasureCodingPolicyResponseProto) Reset() {
	*x = GetErasureCodingPolicyResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[7]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetErasureCodingPolicyResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetErasureCodingPolicyResponseProto) ProtoMessage() {}

func (x *GetErasureCodingPolicyResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[7]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetErasureCodingPolicyResponseProto.ProtoReflect.Descriptor instead.
func (*GetErasureCodingPolicyResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{7}
}

func (x *GetErasureCodingPolicyResponseProto) GetEcPolicy() *ErasureCodingPolicyProto {
	if x != nil {
		return x.EcPolicy
	}
	return nil
}

type AddErasureCodingPoliciesRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	EcPolicies []*ErasureCodingPolicyProto `protobuf:"bytes,1,rep,name=ecPolicies" json:"ecPolicies,omitempty"`
}

func (x *AddErasureCodingPoliciesRequestProto) Reset() {
	*x = AddErasureCodingPoliciesRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[8]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AddErasureCodingPoliciesRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AddErasureCodingPoliciesRequestProto) ProtoMessage() {}

func (x *AddErasureCodingPoliciesRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[8]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AddErasureCodingPoliciesRequestProto.ProtoReflect.Descriptor instead.
func (*AddErasureCodingPoliciesRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{8}
}

func (x *AddErasureCodingPoliciesRequestProto) GetEcPolicies() []*ErasureCodingPolicyProto {
	if x != nil {
		return x.EcPolicies
	}
	return nil
}

type AddErasureCodingPoliciesResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Responses []*AddErasureCodingPolicyResponseProto `protobuf:"bytes,1,rep,name=responses" json:"responses,omitempty"`
}

func (x *AddErasureCodingPoliciesResponseProto) Reset() {
	*x = AddErasureCodingPoliciesResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[9]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AddErasureCodingPoliciesResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AddErasureCodingPoliciesResponseProto) ProtoMessage() {}

func (x *AddErasureCodingPoliciesResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[9]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AddErasureCodingPoliciesResponseProto.ProtoReflect.Descriptor instead.
func (*AddErasureCodingPoliciesResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{9}
}

func (x *AddErasureCodingPoliciesResponseProto) GetResponses() []*AddErasureCodingPolicyResponseProto {
	if x != nil {
		return x.Responses
	}
	return nil
}

type RemoveErasureCodingPolicyRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	EcPolicyName *string `protobuf:"bytes,1,req,name=ecPolicyName" json:"ecPolicyName,omitempty"`
}

func (x *RemoveErasureCodingPolicyRequestProto) Reset() {
	*x = RemoveErasureCodingPolicyRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[10]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveErasureCodingPolicyRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveErasureCodingPolicyRequestProto) ProtoMessage() {}

func (x *RemoveErasureCodingPolicyRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[10]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveErasureCodingPolicyRequestProto.ProtoReflect.Descriptor instead.
func (*RemoveErasureCodingPolicyRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{10}
}

func (x *RemoveErasureCodingPolicyRequestProto) GetEcPolicyName() string {
	if x != nil && x.EcPolicyName != nil {
		return *x.EcPolicyName
	}
	return ""
}

type RemoveErasureCodingPolicyResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *RemoveErasureCodingPolicyResponseProto) Reset() {
	*x = RemoveErasureCodingPolicyResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[11]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveErasureCodingPolicyResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveErasureCodingPolicyResponseProto) ProtoMessage() {}

func (x *RemoveErasureCodingPolicyResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[11]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveErasureCodingPolicyResponseProto.ProtoReflect.Descriptor instead.
func (*RemoveErasureCodingPolicyResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{11}
}

type EnableErasureCodingPolicyRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	EcPolicyName *string `protobuf:"bytes,1,req,name=ecPolicyName" json:"ecPolicyName,omitempty"`
}

func (x *EnableErasureCodingPolicyRequestProto) Reset() {
	*x = EnableErasureCodingPolicyRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[12]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *EnableErasureCodingPolicyRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EnableErasureCodingPolicyRequestProto) ProtoMessage() {}

func (x *EnableErasureCodingPolicyRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[12]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EnableErasureCodingPolicyRequestProto.ProtoReflect.Descriptor instead.
func (*EnableErasureCodingPolicyRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{12}
}

func (x *EnableErasureCodingPolicyRequestProto) GetEcPolicyName() string {
	if x != nil && x.EcPolicyName != nil {
		return *x.EcPolicyName
	}
	return ""
}

type EnableErasureCodingPolicyResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *EnableErasureCodingPolicyResponseProto) Reset() {
	*x = EnableErasureCodingPolicyResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[13]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *EnableErasureCodingPolicyResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EnableErasureCodingPolicyResponseProto) ProtoMessage() {}

func (x *EnableErasureCodingPolicyResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[13]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EnableErasureCodingPolicyResponseProto.ProtoReflect.Descriptor instead.
func (*EnableErasureCodingPolicyResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{13}
}

type DisableErasureCodingPolicyRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	EcPolicyName *string `protobuf:"bytes,1,req,name=ecPolicyName" json:"ecPolicyName,omitempty"`
}

func (x *DisableErasureCodingPolicyRequestProto) Reset() {
	*x = DisableErasureCodingPolicyRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[14]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *DisableErasureCodingPolicyRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DisableErasureCodingPolicyRequestProto) ProtoMessage() {}

func (x *DisableErasureCodingPolicyRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[14]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DisableErasureCodingPolicyRequestProto.ProtoReflect.Descriptor instead.
func (*DisableErasureCodingPolicyRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{14}
}

func (x *DisableErasureCodingPolicyRequestProto) GetEcPolicyName() string {
	if x != nil && x.EcPolicyName != nil {
		return *x.EcPolicyName
	}
	return ""
}

type DisableErasureCodingPolicyResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *DisableErasureCodingPolicyResponseProto) Reset() {
	*x = DisableErasureCodingPolicyResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[15]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *DisableErasureCodingPolicyResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DisableErasureCodingPolicyResponseProto) ProtoMessage() {}

func (x *DisableErasureCodingPolicyResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[15]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DisableErasureCodingPolicyResponseProto.ProtoReflect.Descriptor instead.
func (*DisableErasureCodingPolicyResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{15}
}

type UnsetErasureCodingPolicyRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src *string `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
}

func (x *UnsetErasureCodingPolicyRequestProto) Reset() {
	*x = UnsetErasureCodingPolicyRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[16]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *UnsetErasureCodingPolicyRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UnsetErasureCodingPolicyRequestProto) ProtoMessage() {}

func (x *UnsetErasureCodingPolicyRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[16]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UnsetErasureCodingPolicyRequestProto.ProtoReflect.Descriptor instead.
func (*UnsetErasureCodingPolicyRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{16}
}

func (x *UnsetErasureCodingPolicyRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

type UnsetErasureCodingPolicyResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *UnsetErasureCodingPolicyResponseProto) Reset() {
	*x = UnsetErasureCodingPolicyResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[17]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *UnsetErasureCodingPolicyResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UnsetErasureCodingPolicyResponseProto) ProtoMessage() {}

func (x *UnsetErasureCodingPolicyResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[17]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UnsetErasureCodingPolicyResponseProto.ProtoReflect.Descriptor instead.
func (*UnsetErasureCodingPolicyResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{17}
}

type GetECTopologyResultForPoliciesRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Policies []string `protobuf:"bytes,1,rep,name=policies" json:"policies,omitempty"`
}

func (x *GetECTopologyResultForPoliciesRequestProto) Reset() {
	*x = GetECTopologyResultForPoliciesRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[18]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetECTopologyResultForPoliciesRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetECTopologyResultForPoliciesRequestProto) ProtoMessage() {}

func (x *GetECTopologyResultForPoliciesRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[18]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetECTopologyResultForPoliciesRequestProto.ProtoReflect.Descriptor instead.
func (*GetECTopologyResultForPoliciesRequestProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{18}
}

func (x *GetECTopologyResultForPoliciesRequestProto) GetPolicies() []string {
	if x != nil {
		return x.Policies
	}
	return nil
}

type GetECTopologyResultForPoliciesResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Response *ECTopologyVerifierResultProto `protobuf:"bytes,1,req,name=response" json:"response,omitempty"`
}

func (x *GetECTopologyResultForPoliciesResponseProto) Reset() {
	*x = GetECTopologyResultForPoliciesResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[19]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetECTopologyResultForPoliciesResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetECTopologyResultForPoliciesResponseProto) ProtoMessage() {}

func (x *GetECTopologyResultForPoliciesResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[19]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetECTopologyResultForPoliciesResponseProto.ProtoReflect.Descriptor instead.
func (*GetECTopologyResultForPoliciesResponseProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{19}
}

func (x *GetECTopologyResultForPoliciesResponseProto) GetResponse() *ECTopologyVerifierResultProto {
	if x != nil {
		return x.Response
	}
	return nil
}

//*
// Block erasure coding reconstruction info
type BlockECReconstructionInfoProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Block              *ExtendedBlockProto       `protobuf:"bytes,1,req,name=block" json:"block,omitempty"`
	SourceDnInfos      *DatanodeInfosProto       `protobuf:"bytes,2,req,name=sourceDnInfos" json:"sourceDnInfos,omitempty"`
	TargetDnInfos      *DatanodeInfosProto       `protobuf:"bytes,3,req,name=targetDnInfos" json:"targetDnInfos,omitempty"`
	TargetStorageUuids *StorageUuidsProto        `protobuf:"bytes,4,req,name=targetStorageUuids" json:"targetStorageUuids,omitempty"`
	TargetStorageTypes *StorageTypesProto        `protobuf:"bytes,5,req,name=targetStorageTypes" json:"targetStorageTypes,omitempty"`
	LiveBlockIndices   []byte                    `protobuf:"bytes,6,req,name=liveBlockIndices" json:"liveBlockIndices,omitempty"`
	EcPolicy           *ErasureCodingPolicyProto `protobuf:"bytes,7,req,name=ecPolicy" json:"ecPolicy,omitempty"`
}

func (x *BlockECReconstructionInfoProto) Reset() {
	*x = BlockECReconstructionInfoProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[20]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *BlockECReconstructionInfoProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BlockECReconstructionInfoProto) ProtoMessage() {}

func (x *BlockECReconstructionInfoProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[20]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BlockECReconstructionInfoProto.ProtoReflect.Descriptor instead.
func (*BlockECReconstructionInfoProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{20}
}

func (x *BlockECReconstructionInfoProto) GetBlock() *ExtendedBlockProto {
	if x != nil {
		return x.Block
	}
	return nil
}

func (x *BlockECReconstructionInfoProto) GetSourceDnInfos() *DatanodeInfosProto {
	if x != nil {
		return x.SourceDnInfos
	}
	return nil
}

func (x *BlockECReconstructionInfoProto) GetTargetDnInfos() *DatanodeInfosProto {
	if x != nil {
		return x.TargetDnInfos
	}
	return nil
}

func (x *BlockECReconstructionInfoProto) GetTargetStorageUuids() *StorageUuidsProto {
	if x != nil {
		return x.TargetStorageUuids
	}
	return nil
}

func (x *BlockECReconstructionInfoProto) GetTargetStorageTypes() *StorageTypesProto {
	if x != nil {
		return x.TargetStorageTypes
	}
	return nil
}

func (x *BlockECReconstructionInfoProto) GetLiveBlockIndices() []byte {
	if x != nil {
		return x.LiveBlockIndices
	}
	return nil
}

func (x *BlockECReconstructionInfoProto) GetEcPolicy() *ErasureCodingPolicyProto {
	if x != nil {
		return x.EcPolicy
	}
	return nil
}

//*
// Codec and it's corresponding coders
type CodecProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Codec  *string `protobuf:"bytes,1,req,name=codec" json:"codec,omitempty"`
	Coders *string `protobuf:"bytes,2,req,name=coders" json:"coders,omitempty"`
}

func (x *CodecProto) Reset() {
	*x = CodecProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_erasurecoding_proto_msgTypes[21]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *CodecProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CodecProto) ProtoMessage() {}

func (x *CodecProto) ProtoReflect() protoreflect.Message {
	mi := &file_erasurecoding_proto_msgTypes[21]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CodecProto.ProtoReflect.Descriptor instead.
func (*CodecProto) Descriptor() ([]byte, []int) {
	return file_erasurecoding_proto_rawDescGZIP(), []int{21}
}

func (x *CodecProto) GetCodec() string {
	if x != nil && x.Codec != nil {
		return *x.Codec
	}
	return ""
}

func (x *CodecProto) GetCoders() string {
	if x != nil && x.Coders != nil {
		return *x.Coders
	}
	return ""
}

var File_erasurecoding_proto protoreflect.FileDescriptor

var file_erasurecoding_proto_rawDesc = []byte{
	0x0a, 0x13, 0x65, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x63, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x0b, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64,
	0x66, 0x73, 0x1a, 0x0a, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x5a,
	0x0a, 0x22, 0x53, 0x65, 0x74, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69,
	0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28,
	0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x12, 0x22, 0x0a, 0x0c, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69,
	0x63, 0x79, 0x4e, 0x61, 0x6d, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09, 0x52, 0x0c, 0x65, 0x63,
	0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x4e, 0x61, 0x6d, 0x65, 0x22, 0x25, 0x0a, 0x23, 0x53, 0x65,
	0x74, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f,
	0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74,
	0x6f, 0x22, 0x26, 0x0a, 0x24, 0x47, 0x65, 0x74, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43,
	0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x69, 0x65, 0x73, 0x52, 0x65, 0x71,
	0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x6e, 0x0a, 0x25, 0x47, 0x65, 0x74,
	0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c,
	0x69, 0x63, 0x69, 0x65, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f,
	0x74, 0x6f, 0x12, 0x45, 0x0a, 0x0a, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x69, 0x65, 0x73,
	0x18, 0x01, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x25, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e,
	0x68, 0x64, 0x66, 0x73, 0x2e, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69,
	0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x0a, 0x65,
	0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x69, 0x65, 0x73, 0x22, 0x24, 0x0a, 0x22, 0x47, 0x65, 0x74,
	0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x43, 0x6f, 0x64,
	0x65, 0x63, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22,
	0x54, 0x0a, 0x23, 0x47, 0x65, 0x74, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64,
	0x69, 0x6e, 0x67, 0x43, 0x6f, 0x64, 0x65, 0x63, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73,
	0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x2d, 0x0a, 0x05, 0x63, 0x6f, 0x64, 0x65, 0x63, 0x18,
	0x01, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x17, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68,
	0x64, 0x66, 0x73, 0x2e, 0x43, 0x6f, 0x64, 0x65, 0x63, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x05,
	0x63, 0x6f, 0x64, 0x65, 0x63, 0x22, 0x36, 0x0a, 0x22, 0x47, 0x65, 0x74, 0x45, 0x72, 0x61, 0x73,
	0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52,
	0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73,
	0x72, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x22, 0x68, 0x0a,
	0x23, 0x47, 0x65, 0x74, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e,
	0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x12, 0x41, 0x0a, 0x08, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79,
	0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x25, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e,
	0x68, 0x64, 0x66, 0x73, 0x2e, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69,
	0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x08, 0x65,
	0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x22, 0x6d, 0x0a, 0x24, 0x41, 0x64, 0x64, 0x45, 0x72,
	0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63,
	0x69, 0x65, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12,
	0x45, 0x0a, 0x0a, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x69, 0x65, 0x73, 0x18, 0x01, 0x20,
	0x03, 0x28, 0x0b, 0x32, 0x25, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66,
	0x73, 0x2e, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50,
	0x6f, 0x6c, 0x69, 0x63, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x0a, 0x65, 0x63, 0x50, 0x6f,
	0x6c, 0x69, 0x63, 0x69, 0x65, 0x73, 0x22, 0x77, 0x0a, 0x25, 0x41, 0x64, 0x64, 0x45, 0x72, 0x61,
	0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x69,
	0x65, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12,
	0x4e, 0x0a, 0x09, 0x72, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x73, 0x18, 0x01, 0x20, 0x03,
	0x28, 0x0b, 0x32, 0x30, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73,
	0x2e, 0x41, 0x64, 0x64, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e,
	0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x52, 0x09, 0x72, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x73, 0x22,
	0x4b, 0x0a, 0x25, 0x52, 0x65, 0x6d, 0x6f, 0x76, 0x65, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65,
	0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x71, 0x75,
	0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x22, 0x0a, 0x0c, 0x65, 0x63, 0x50, 0x6f,
	0x6c, 0x69, 0x63, 0x79, 0x4e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x0c,
	0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x4e, 0x61, 0x6d, 0x65, 0x22, 0x28, 0x0a, 0x26,
	0x52, 0x65, 0x6d, 0x6f, 0x76, 0x65, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64,
	0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73,
	0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x4b, 0x0a, 0x25, 0x45, 0x6e, 0x61, 0x62, 0x6c, 0x65,
	0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c,
	0x69, 0x63, 0x79, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12,
	0x22, 0x0a, 0x0c, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x4e, 0x61, 0x6d, 0x65, 0x18,
	0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x0c, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x4e,
	0x61, 0x6d, 0x65, 0x22, 0x28, 0x0a, 0x26, 0x45, 0x6e, 0x61, 0x62, 0x6c, 0x65, 0x45, 0x72, 0x61,
	0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79,
	0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x4c, 0x0a,
	0x26, 0x44, 0x69, 0x73, 0x61, 0x62, 0x6c, 0x65, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43,
	0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x71, 0x75, 0x65,
	0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x22, 0x0a, 0x0c, 0x65, 0x63, 0x50, 0x6f, 0x6c,
	0x69, 0x63, 0x79, 0x4e, 0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x0c, 0x65,
	0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x4e, 0x61, 0x6d, 0x65, 0x22, 0x29, 0x0a, 0x27, 0x44,
	0x69, 0x73, 0x61, 0x62, 0x6c, 0x65, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64,
	0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73,
	0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x38, 0x0a, 0x24, 0x55, 0x6e, 0x73, 0x65, 0x74, 0x45,
	0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69,
	0x63, 0x79, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10,
	0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x03, 0x73, 0x72, 0x63,
	0x22, 0x27, 0x0a, 0x25, 0x55, 0x6e, 0x73, 0x65, 0x74, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65,
	0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x52, 0x65, 0x73, 0x70,
	0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x48, 0x0a, 0x2a, 0x47, 0x65, 0x74,
	0x45, 0x43, 0x54, 0x6f, 0x70, 0x6f, 0x6c, 0x6f, 0x67, 0x79, 0x52, 0x65, 0x73, 0x75, 0x6c, 0x74,
	0x46, 0x6f, 0x72, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x69, 0x65, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65,
	0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x1a, 0x0a, 0x08, 0x70, 0x6f, 0x6c, 0x69, 0x63,
	0x69, 0x65, 0x73, 0x18, 0x01, 0x20, 0x03, 0x28, 0x09, 0x52, 0x08, 0x70, 0x6f, 0x6c, 0x69, 0x63,
	0x69, 0x65, 0x73, 0x22, 0x75, 0x0a, 0x2b, 0x47, 0x65, 0x74, 0x45, 0x43, 0x54, 0x6f, 0x70, 0x6f,
	0x6c, 0x6f, 0x67, 0x79, 0x52, 0x65, 0x73, 0x75, 0x6c, 0x74, 0x46, 0x6f, 0x72, 0x50, 0x6f, 0x6c,
	0x69, 0x63, 0x69, 0x65, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f,
	0x74, 0x6f, 0x12, 0x46, 0x0a, 0x08, 0x72, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x18, 0x01,
	0x20, 0x02, 0x28, 0x0b, 0x32, 0x2a, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64,
	0x66, 0x73, 0x2e, 0x45, 0x43, 0x54, 0x6f, 0x70, 0x6f, 0x6c, 0x6f, 0x67, 0x79, 0x56, 0x65, 0x72,
	0x69, 0x66, 0x69, 0x65, 0x72, 0x52, 0x65, 0x73, 0x75, 0x6c, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f,
	0x52, 0x08, 0x72, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x22, 0xf4, 0x03, 0x0a, 0x1e, 0x42,
	0x6c, 0x6f, 0x63, 0x6b, 0x45, 0x43, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x73, 0x74, 0x72, 0x75, 0x63,
	0x74, 0x69, 0x6f, 0x6e, 0x49, 0x6e, 0x66, 0x6f, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x35, 0x0a,
	0x05, 0x62, 0x6c, 0x6f, 0x63, 0x6b, 0x18, 0x01, 0x20, 0x02, 0x28, 0x0b, 0x32, 0x1f, 0x2e, 0x68,
	0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x45, 0x78, 0x74, 0x65, 0x6e,
	0x64, 0x65, 0x64, 0x42, 0x6c, 0x6f, 0x63, 0x6b, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x05, 0x62,
	0x6c, 0x6f, 0x63, 0x6b, 0x12, 0x45, 0x0a, 0x0d, 0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x44, 0x6e,
	0x49, 0x6e, 0x66, 0x6f, 0x73, 0x18, 0x02, 0x20, 0x02, 0x28, 0x0b, 0x32, 0x1f, 0x2e, 0x68, 0x61,
	0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x44, 0x61, 0x74, 0x61, 0x6e, 0x6f,
	0x64, 0x65, 0x49, 0x6e, 0x66, 0x6f, 0x73, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x0d, 0x73, 0x6f,
	0x75, 0x72, 0x63, 0x65, 0x44, 0x6e, 0x49, 0x6e, 0x66, 0x6f, 0x73, 0x12, 0x45, 0x0a, 0x0d, 0x74,
	0x61, 0x72, 0x67, 0x65, 0x74, 0x44, 0x6e, 0x49, 0x6e, 0x66, 0x6f, 0x73, 0x18, 0x03, 0x20, 0x02,
	0x28, 0x0b, 0x32, 0x1f, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73,
	0x2e, 0x44, 0x61, 0x74, 0x61, 0x6e, 0x6f, 0x64, 0x65, 0x49, 0x6e, 0x66, 0x6f, 0x73, 0x50, 0x72,
	0x6f, 0x74, 0x6f, 0x52, 0x0d, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x44, 0x6e, 0x49, 0x6e, 0x66,
	0x6f, 0x73, 0x12, 0x4e, 0x0a, 0x12, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x53, 0x74, 0x6f, 0x72,
	0x61, 0x67, 0x65, 0x55, 0x75, 0x69, 0x64, 0x73, 0x18, 0x04, 0x20, 0x02, 0x28, 0x0b, 0x32, 0x1e,
	0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x53, 0x74, 0x6f,
	0x72, 0x61, 0x67, 0x65, 0x55, 0x75, 0x69, 0x64, 0x73, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x12,
	0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x53, 0x74, 0x6f, 0x72, 0x61, 0x67, 0x65, 0x55, 0x75, 0x69,
	0x64, 0x73, 0x12, 0x4e, 0x0a, 0x12, 0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x53, 0x74, 0x6f, 0x72,
	0x61, 0x67, 0x65, 0x54, 0x79, 0x70, 0x65, 0x73, 0x18, 0x05, 0x20, 0x02, 0x28, 0x0b, 0x32, 0x1e,
	0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x53, 0x74, 0x6f,
	0x72, 0x61, 0x67, 0x65, 0x54, 0x79, 0x70, 0x65, 0x73, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x12,
	0x74, 0x61, 0x72, 0x67, 0x65, 0x74, 0x53, 0x74, 0x6f, 0x72, 0x61, 0x67, 0x65, 0x54, 0x79, 0x70,
	0x65, 0x73, 0x12, 0x2a, 0x0a, 0x10, 0x6c, 0x69, 0x76, 0x65, 0x42, 0x6c, 0x6f, 0x63, 0x6b, 0x49,
	0x6e, 0x64, 0x69, 0x63, 0x65, 0x73, 0x18, 0x06, 0x20, 0x02, 0x28, 0x0c, 0x52, 0x10, 0x6c, 0x69,
	0x76, 0x65, 0x42, 0x6c, 0x6f, 0x63, 0x6b, 0x49, 0x6e, 0x64, 0x69, 0x63, 0x65, 0x73, 0x12, 0x41,
	0x0a, 0x08, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63, 0x79, 0x18, 0x07, 0x20, 0x02, 0x28, 0x0b,
	0x32, 0x25, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x45,
	0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43, 0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x6f, 0x6c, 0x69,
	0x63, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x08, 0x65, 0x63, 0x50, 0x6f, 0x6c, 0x69, 0x63,
	0x79, 0x22, 0x3a, 0x0a, 0x0a, 0x43, 0x6f, 0x64, 0x65, 0x63, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12,
	0x14, 0x0a, 0x05, 0x63, 0x6f, 0x64, 0x65, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x05,
	0x63, 0x6f, 0x64, 0x65, 0x63, 0x12, 0x16, 0x0a, 0x06, 0x63, 0x6f, 0x64, 0x65, 0x72, 0x73, 0x18,
	0x02, 0x20, 0x02, 0x28, 0x09, 0x52, 0x06, 0x63, 0x6f, 0x64, 0x65, 0x72, 0x73, 0x42, 0x7b, 0x0a,
	0x25, 0x6f, 0x72, 0x67, 0x2e, 0x61, 0x70, 0x61, 0x63, 0x68, 0x65, 0x2e, 0x68, 0x61, 0x64, 0x6f,
	0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x42, 0x13, 0x45, 0x72, 0x61, 0x73, 0x75, 0x72, 0x65, 0x43,
	0x6f, 0x64, 0x69, 0x6e, 0x67, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x73, 0x5a, 0x3a, 0x67, 0x69, 0x74,
	0x68, 0x75, 0x62, 0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x63, 0x6f, 0x6c, 0x69, 0x6e, 0x6d, 0x61, 0x72,
	0x63, 0x2f, 0x68, 0x64, 0x66, 0x73, 0x2f, 0x76, 0x32, 0x2f, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e,
	0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2f, 0x68, 0x61, 0x64, 0x6f,
	0x6f, 0x70, 0x5f, 0x68, 0x64, 0x66, 0x73, 0xa0, 0x01, 0x01,
}

var (
	file_erasurecoding_proto_rawDescOnce sync.Once
	file_erasurecoding_proto_rawDescData = file_erasurecoding_proto_rawDesc
)

func file_erasurecoding_proto_rawDescGZIP() []byte {
	file_erasurecoding_proto_rawDescOnce.Do(func() {
		file_erasurecoding_proto_rawDescData = protoimpl.X.CompressGZIP(file_erasurecoding_proto_rawDescData)
	})
	return file_erasurecoding_proto_rawDescData
}

var file_erasurecoding_proto_msgTypes = make([]protoimpl.MessageInfo, 22)
var file_erasurecoding_proto_goTypes = []interface{}{
	(*SetErasureCodingPolicyRequestProto)(nil),          // 0: hadoop.hdfs.SetErasureCodingPolicyRequestProto
	(*SetErasureCodingPolicyResponseProto)(nil),         // 1: hadoop.hdfs.SetErasureCodingPolicyResponseProto
	(*GetErasureCodingPoliciesRequestProto)(nil),        // 2: hadoop.hdfs.GetErasureCodingPoliciesRequestProto
	(*GetErasureCodingPoliciesResponseProto)(nil),       // 3: hadoop.hdfs.GetErasureCodingPoliciesResponseProto
	(*GetErasureCodingCodecsRequestProto)(nil),          // 4: hadoop.hdfs.GetErasureCodingCodecsRequestProto
	(*GetErasureCodingCodecsResponseProto)(nil),         // 5: hadoop.hdfs.GetErasureCodingCodecsResponseProto
	(*GetErasureCodingPolicyRequestProto)(nil),          // 6: hadoop.hdfs.GetErasureCodingPolicyRequestProto
	(*GetErasureCodingPolicyResponseProto)(nil),         // 7: hadoop.hdfs.GetErasureCodingPolicyResponseProto
	(*AddErasureCodingPoliciesRequestProto)(nil),        // 8: hadoop.hdfs.AddErasureCodingPoliciesRequestProto
	(*AddErasureCodingPoliciesResponseProto)(nil),       // 9: hadoop.hdfs.AddErasureCodingPoliciesResponseProto
	(*RemoveErasureCodingPolicyRequestProto)(nil),       // 10: hadoop.hdfs.RemoveErasureCodingPolicyRequestProto
	(*RemoveErasureCodingPolicyResponseProto)(nil),      // 11: hadoop.hdfs.RemoveErasureCodingPolicyResponseProto
	(*EnableErasureCodingPolicyRequestProto)(nil),       // 12: hadoop.hdfs.EnableErasureCodingPolicyRequestProto
	(*EnableErasureCodingPolicyResponseProto)(nil),      // 13: hadoop.hdfs.EnableErasureCodingPolicyResponseProto
	(*DisableErasureCodingPolicyRequestProto)(nil),      // 14: hadoop.hdfs.DisableErasureCodingPolicyRequestProto
	(*DisableErasureCodingPolicyResponseProto)(nil),     // 15: hadoop.hdfs.DisableErasureCodingPolicyResponseProto
	(*UnsetErasureCodingPolicyRequestProto)(nil),        // 16: hadoop.hdfs.UnsetErasureCodingPolicyRequestProto
	(*UnsetErasureCodingPolicyResponseProto)(nil),       // 17: hadoop.hdfs.UnsetErasureCodingPolicyResponseProto
	(*GetECTopologyResultForPoliciesRequestProto)(nil),  // 18: hadoop.hdfs.GetECTopologyResultForPoliciesRequestProto
	(*GetECTopologyResultForPoliciesResponseProto)(nil), // 19: hadoop.hdfs.GetECTopologyResultForPoliciesResponseProto
	(*BlockECReconstructionInfoProto)(nil),              // 20: hadoop.hdfs.BlockECReconstructionInfoProto
	(*CodecProto)(nil),                                  // 21: hadoop.hdfs.CodecProto
	(*ErasureCodingPolicyProto)(nil),                    // 22: hadoop.hdfs.ErasureCodingPolicyProto
	(*AddErasureCodingPolicyResponseProto)(nil),         // 23: hadoop.hdfs.AddErasureCodingPolicyResponseProto
	(*ECTopologyVerifierResultProto)(nil),               // 24: hadoop.hdfs.ECTopologyVerifierResultProto
	(*ExtendedBlockProto)(nil),                          // 25: hadoop.hdfs.ExtendedBlockProto
	(*DatanodeInfosProto)(nil),                          // 26: hadoop.hdfs.DatanodeInfosProto
	(*StorageUuidsProto)(nil),                           // 27: hadoop.hdfs.StorageUuidsProto
	(*StorageTypesProto)(nil),                           // 28: hadoop.hdfs.StorageTypesProto
}
var file_erasurecoding_proto_depIdxs = []int32{
	22, // 0: hadoop.hdfs.GetErasureCodingPoliciesResponseProto.ecPolicies:type_name -> hadoop.hdfs.ErasureCodingPolicyProto
	21, // 1: hadoop.hdfs.GetErasureCodingCodecsResponseProto.codec:type_name -> hadoop.hdfs.CodecProto
	22, // 2: hadoop.hdfs.GetErasureCodingPolicyResponseProto.ecPolicy:type_name -> hadoop.hdfs.ErasureCodingPolicyProto
	22, // 3: hadoop.hdfs.AddErasureCodingPoliciesRequestProto.ecPolicies:type_name -> hadoop.hdfs.ErasureCodingPolicyProto
	23, // 4: hadoop.hdfs.AddErasureCodingPoliciesResponseProto.responses:type_name -> hadoop.hdfs.AddErasureCodingPolicyResponseProto
	24, // 5: hadoop.hdfs.GetECTopologyResultForPoliciesResponseProto.response:type_name -> hadoop.hdfs.ECTopologyVerifierResultProto
	25, // 6: hadoop.hdfs.BlockECReconstructionInfoProto.block:type_name -> hadoop.hdfs.ExtendedBlockProto
	26, // 7: hadoop.hdfs.BlockECReconstructionInfoProto.sourceDnInfos:type_name -> hadoop.hdfs.DatanodeInfosProto
	26, // 8: hadoop.hdfs.BlockECReconstructionInfoProto.targetDnInfos:type_name -> hadoop.hdfs.DatanodeInfosProto
	27, // 9: hadoop.hdfs.BlockECReconstructionInfoProto.targetStorageUuids:type_name -> hadoop.hdfs.StorageUuidsProto
	28, // 10: hadoop.hdfs.BlockECReconstructionInfoProto.targetStorageTypes:type_name -> hadoop.hdfs.StorageTypesProto
	22, // 11: hadoop.hdfs.BlockECReconstructionInfoProto.ecPolicy:type_name -> hadoop.hdfs.ErasureCodingPolicyProto
	12, // [12:12] is the sub-list for method output_type
	12, // [12:12] is the sub-list for method input_type
	12, // [12:12] is the sub-list for extension type_name
	12, // [12:12] is the sub-list for extension extendee
	0,  // [0:12] is the sub-list for field type_name
}

func init() { file_erasurecoding_proto_init() }
func file_erasurecoding_proto_init() {
	if File_erasurecoding_proto != nil {
		return
	}
	file_hdfs_proto_init()
	if !protoimpl.UnsafeEnabled {
		file_erasurecoding_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*SetErasureCodingPolicyRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*SetErasureCodingPolicyResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetErasureCodingPoliciesRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[3].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetErasureCodingPoliciesResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[4].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetErasureCodingCodecsRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[5].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetErasureCodingCodecsResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[6].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetErasureCodingPolicyRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[7].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetErasureCodingPolicyResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[8].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AddErasureCodingPoliciesRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[9].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AddErasureCodingPoliciesResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[10].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveErasureCodingPolicyRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[11].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveErasureCodingPolicyResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[12].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*EnableErasureCodingPolicyRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[13].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*EnableErasureCodingPolicyResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[14].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*DisableErasureCodingPolicyRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[15].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*DisableErasureCodingPolicyResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[16].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*UnsetErasureCodingPolicyRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[17].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*UnsetErasureCodingPolicyResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[18].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetECTopologyResultForPoliciesRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[19].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetECTopologyResultForPoliciesResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[20].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*BlockECReconstructionInfoProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_erasurecoding_proto_msgTypes[21].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*CodecProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_erasurecoding_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   22,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_erasurecoding_proto_goTypes,
		DependencyIndexes: file_erasurecoding_proto_depIdxs,
		MessageInfos:      file_erasurecoding_proto_msgTypes,
	}.Build()
	File_erasurecoding_proto = out.File
	file_erasurecoding_proto_rawDesc = nil
	file_erasurecoding_proto_goTypes = nil
	file_erasurecoding_proto_depIdxs = nil
}
