//*
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.27.1
// 	protoc        v3.19.4
// source: ReconfigurationProtocol.proto

package hadoop_hdfs

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

//* Asks NN/DN to reload configuration file.
type StartReconfigurationRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *StartReconfigurationRequestProto) Reset() {
	*x = StartReconfigurationRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_ReconfigurationProtocol_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *StartReconfigurationRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*StartReconfigurationRequestProto) ProtoMessage() {}

func (x *StartReconfigurationRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_ReconfigurationProtocol_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use StartReconfigurationRequestProto.ProtoReflect.Descriptor instead.
func (*StartReconfigurationRequestProto) Descriptor() ([]byte, []int) {
	return file_ReconfigurationProtocol_proto_rawDescGZIP(), []int{0}
}

type StartReconfigurationResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *StartReconfigurationResponseProto) Reset() {
	*x = StartReconfigurationResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_ReconfigurationProtocol_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *StartReconfigurationResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*StartReconfigurationResponseProto) ProtoMessage() {}

func (x *StartReconfigurationResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_ReconfigurationProtocol_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use StartReconfigurationResponseProto.ProtoReflect.Descriptor instead.
func (*StartReconfigurationResponseProto) Descriptor() ([]byte, []int) {
	return file_ReconfigurationProtocol_proto_rawDescGZIP(), []int{1}
}

//* Query the running status of reconfiguration process
type GetReconfigurationStatusRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *GetReconfigurationStatusRequestProto) Reset() {
	*x = GetReconfigurationStatusRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_ReconfigurationProtocol_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetReconfigurationStatusRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetReconfigurationStatusRequestProto) ProtoMessage() {}

func (x *GetReconfigurationStatusRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_ReconfigurationProtocol_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetReconfigurationStatusRequestProto.ProtoReflect.Descriptor instead.
func (*GetReconfigurationStatusRequestProto) Descriptor() ([]byte, []int) {
	return file_ReconfigurationProtocol_proto_rawDescGZIP(), []int{2}
}

type GetReconfigurationStatusConfigChangeProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Name         *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	OldValue     *string `protobuf:"bytes,2,req,name=oldValue" json:"oldValue,omitempty"`
	NewValue     *string `protobuf:"bytes,3,opt,name=newValue" json:"newValue,omitempty"`
	ErrorMessage *string `protobuf:"bytes,4,opt,name=errorMessage" json:"errorMessage,omitempty"` // It is empty if success.
}

func (x *GetReconfigurationStatusConfigChangeProto) Reset() {
	*x = GetReconfigurationStatusConfigChangeProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_ReconfigurationProtocol_proto_msgTypes[3]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetReconfigurationStatusConfigChangeProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetReconfigurationStatusConfigChangeProto) ProtoMessage() {}

func (x *GetReconfigurationStatusConfigChangeProto) ProtoReflect() protoreflect.Message {
	mi := &file_ReconfigurationProtocol_proto_msgTypes[3]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetReconfigurationStatusConfigChangeProto.ProtoReflect.Descriptor instead.
func (*GetReconfigurationStatusConfigChangeProto) Descriptor() ([]byte, []int) {
	return file_ReconfigurationProtocol_proto_rawDescGZIP(), []int{3}
}

func (x *GetReconfigurationStatusConfigChangeProto) GetName() string {
	if x != nil && x.Name != nil {
		return *x.Name
	}
	return ""
}

func (x *GetReconfigurationStatusConfigChangeProto) GetOldValue() string {
	if x != nil && x.OldValue != nil {
		return *x.OldValue
	}
	return ""
}

func (x *GetReconfigurationStatusConfigChangeProto) GetNewValue() string {
	if x != nil && x.NewValue != nil {
		return *x.NewValue
	}
	return ""
}

func (x *GetReconfigurationStatusConfigChangeProto) GetErrorMessage() string {
	if x != nil && x.ErrorMessage != nil {
		return *x.ErrorMessage
	}
	return ""
}

type GetReconfigurationStatusResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	StartTime *int64                                       `protobuf:"varint,1,req,name=startTime" json:"startTime,omitempty"`
	EndTime   *int64                                       `protobuf:"varint,2,opt,name=endTime" json:"endTime,omitempty"`
	Changes   []*GetReconfigurationStatusConfigChangeProto `protobuf:"bytes,3,rep,name=changes" json:"changes,omitempty"`
}

func (x *GetReconfigurationStatusResponseProto) Reset() {
	*x = GetReconfigurationStatusResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_ReconfigurationProtocol_proto_msgTypes[4]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetReconfigurationStatusResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetReconfigurationStatusResponseProto) ProtoMessage() {}

func (x *GetReconfigurationStatusResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_ReconfigurationProtocol_proto_msgTypes[4]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetReconfigurationStatusResponseProto.ProtoReflect.Descriptor instead.
func (*GetReconfigurationStatusResponseProto) Descriptor() ([]byte, []int) {
	return file_ReconfigurationProtocol_proto_rawDescGZIP(), []int{4}
}

func (x *GetReconfigurationStatusResponseProto) GetStartTime() int64 {
	if x != nil && x.StartTime != nil {
		return *x.StartTime
	}
	return 0
}

func (x *GetReconfigurationStatusResponseProto) GetEndTime() int64 {
	if x != nil && x.EndTime != nil {
		return *x.EndTime
	}
	return 0
}

func (x *GetReconfigurationStatusResponseProto) GetChanges() []*GetReconfigurationStatusConfigChangeProto {
	if x != nil {
		return x.Changes
	}
	return nil
}

//* Query the reconfigurable properties on NN/DN.
type ListReconfigurablePropertiesRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *ListReconfigurablePropertiesRequestProto) Reset() {
	*x = ListReconfigurablePropertiesRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_ReconfigurationProtocol_proto_msgTypes[5]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ListReconfigurablePropertiesRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListReconfigurablePropertiesRequestProto) ProtoMessage() {}

func (x *ListReconfigurablePropertiesRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_ReconfigurationProtocol_proto_msgTypes[5]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListReconfigurablePropertiesRequestProto.ProtoReflect.Descriptor instead.
func (*ListReconfigurablePropertiesRequestProto) Descriptor() ([]byte, []int) {
	return file_ReconfigurationProtocol_proto_rawDescGZIP(), []int{5}
}

type ListReconfigurablePropertiesResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Name []string `protobuf:"bytes,1,rep,name=name" json:"name,omitempty"`
}

func (x *ListReconfigurablePropertiesResponseProto) Reset() {
	*x = ListReconfigurablePropertiesResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_ReconfigurationProtocol_proto_msgTypes[6]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ListReconfigurablePropertiesResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListReconfigurablePropertiesResponseProto) ProtoMessage() {}

func (x *ListReconfigurablePropertiesResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_ReconfigurationProtocol_proto_msgTypes[6]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListReconfigurablePropertiesResponseProto.ProtoReflect.Descriptor instead.
func (*ListReconfigurablePropertiesResponseProto) Descriptor() ([]byte, []int) {
	return file_ReconfigurationProtocol_proto_rawDescGZIP(), []int{6}
}

func (x *ListReconfigurablePropertiesResponseProto) GetName() []string {
	if x != nil {
		return x.Name
	}
	return nil
}

var File_ReconfigurationProtocol_proto protoreflect.FileDescriptor

var file_ReconfigurationProtocol_proto_rawDesc = []byte{
	0x0a, 0x1d, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f,
	0x6e, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12,
	0x0b, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x22, 0x22, 0x0a, 0x20,
	0x53, 0x74, 0x61, 0x72, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61,
	0x74, 0x69, 0x6f, 0x6e, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f,
	0x22, 0x23, 0x0a, 0x21, 0x53, 0x74, 0x61, 0x72, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69,
	0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65,
	0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x26, 0x0a, 0x24, 0x47, 0x65, 0x74, 0x52, 0x65, 0x63, 0x6f,
	0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x53, 0x74, 0x61, 0x74, 0x75,
	0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x9b, 0x01,
	0x0a, 0x29, 0x47, 0x65, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61,
	0x74, 0x69, 0x6f, 0x6e, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67,
	0x43, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x12, 0x0a, 0x04, 0x6e,
	0x61, 0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x12,
	0x1a, 0x0a, 0x08, 0x6f, 0x6c, 0x64, 0x56, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x02, 0x28,
	0x09, 0x52, 0x08, 0x6f, 0x6c, 0x64, 0x56, 0x61, 0x6c, 0x75, 0x65, 0x12, 0x1a, 0x0a, 0x08, 0x6e,
	0x65, 0x77, 0x56, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x09, 0x52, 0x08, 0x6e,
	0x65, 0x77, 0x56, 0x61, 0x6c, 0x75, 0x65, 0x12, 0x22, 0x0a, 0x0c, 0x65, 0x72, 0x72, 0x6f, 0x72,
	0x4d, 0x65, 0x73, 0x73, 0x61, 0x67, 0x65, 0x18, 0x04, 0x20, 0x01, 0x28, 0x09, 0x52, 0x0c, 0x65,
	0x72, 0x72, 0x6f, 0x72, 0x4d, 0x65, 0x73, 0x73, 0x61, 0x67, 0x65, 0x22, 0xb1, 0x01, 0x0a, 0x25,
	0x47, 0x65, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69,
	0x6f, 0x6e, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65,
	0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x1c, 0x0a, 0x09, 0x73, 0x74, 0x61, 0x72, 0x74, 0x54, 0x69,
	0x6d, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28, 0x03, 0x52, 0x09, 0x73, 0x74, 0x61, 0x72, 0x74, 0x54,
	0x69, 0x6d, 0x65, 0x12, 0x18, 0x0a, 0x07, 0x65, 0x6e, 0x64, 0x54, 0x69, 0x6d, 0x65, 0x18, 0x02,
	0x20, 0x01, 0x28, 0x03, 0x52, 0x07, 0x65, 0x6e, 0x64, 0x54, 0x69, 0x6d, 0x65, 0x12, 0x50, 0x0a,
	0x07, 0x63, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x18, 0x03, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x36,
	0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x47, 0x65, 0x74,
	0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x53,
	0x74, 0x61, 0x74, 0x75, 0x73, 0x43, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x43, 0x68, 0x61, 0x6e, 0x67,
	0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x07, 0x63, 0x68, 0x61, 0x6e, 0x67, 0x65, 0x73, 0x22,
	0x2a, 0x0a, 0x28, 0x4c, 0x69, 0x73, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75,
	0x72, 0x61, 0x62, 0x6c, 0x65, 0x50, 0x72, 0x6f, 0x70, 0x65, 0x72, 0x74, 0x69, 0x65, 0x73, 0x52,
	0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x3f, 0x0a, 0x29, 0x4c,
	0x69, 0x73, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x62, 0x6c,
	0x65, 0x50, 0x72, 0x6f, 0x70, 0x65, 0x72, 0x74, 0x69, 0x65, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f,
	0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65,
	0x18, 0x01, 0x20, 0x03, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x32, 0xab, 0x03, 0x0a,
	0x1e, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e,
	0x50, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x53, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x12,
	0x81, 0x01, 0x0a, 0x18, 0x67, 0x65, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75,
	0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x12, 0x31, 0x2e, 0x68,
	0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x47, 0x65, 0x74, 0x52, 0x65,
	0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x53, 0x74, 0x61,
	0x74, 0x75, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x1a,
	0x32, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x47, 0x65,
	0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e,
	0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72,
	0x6f, 0x74, 0x6f, 0x12, 0x75, 0x0a, 0x14, 0x73, 0x74, 0x61, 0x72, 0x74, 0x52, 0x65, 0x63, 0x6f,
	0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x12, 0x2d, 0x2e, 0x68, 0x61,
	0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x53, 0x74, 0x61, 0x72, 0x74, 0x52,
	0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x52, 0x65,
	0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x1a, 0x2e, 0x2e, 0x68, 0x61, 0x64,
	0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x53, 0x74, 0x61, 0x72, 0x74, 0x52, 0x65,
	0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x74, 0x69, 0x6f, 0x6e, 0x52, 0x65, 0x73,
	0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x8d, 0x01, 0x0a, 0x1c, 0x6c,
	0x69, 0x73, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x62, 0x6c,
	0x65, 0x50, 0x72, 0x6f, 0x70, 0x65, 0x72, 0x74, 0x69, 0x65, 0x73, 0x12, 0x35, 0x2e, 0x68, 0x61,
	0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x4c, 0x69, 0x73, 0x74, 0x52, 0x65,
	0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61, 0x62, 0x6c, 0x65, 0x50, 0x72, 0x6f, 0x70,
	0x65, 0x72, 0x74, 0x69, 0x65, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f,
	0x74, 0x6f, 0x1a, 0x36, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73,
	0x2e, 0x4c, 0x69, 0x73, 0x74, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72, 0x61,
	0x62, 0x6c, 0x65, 0x50, 0x72, 0x6f, 0x70, 0x65, 0x72, 0x74, 0x69, 0x65, 0x73, 0x52, 0x65, 0x73,
	0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x42, 0x88, 0x01, 0x0a, 0x25, 0x6f,
	0x72, 0x67, 0x2e, 0x61, 0x70, 0x61, 0x63, 0x68, 0x65, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70,
	0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x42, 0x1d, 0x52, 0x65, 0x63, 0x6f, 0x6e, 0x66, 0x69, 0x67, 0x75, 0x72,
	0x61, 0x74, 0x69, 0x6f, 0x6e, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x50, 0x72, 0x6f,
	0x74, 0x6f, 0x73, 0x5a, 0x3a, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62, 0x2e, 0x63, 0x6f, 0x6d, 0x2f,
	0x63, 0x6f, 0x6c, 0x69, 0x6e, 0x6d, 0x61, 0x72, 0x63, 0x2f, 0x68, 0x64, 0x66, 0x73, 0x2f, 0x76,
	0x32, 0x2f, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x63, 0x6f, 0x6c, 0x2f, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x5f, 0x68, 0x64, 0x66, 0x73, 0x88,
	0x01, 0x01, 0xa0, 0x01, 0x01,
}

var (
	file_ReconfigurationProtocol_proto_rawDescOnce sync.Once
	file_ReconfigurationProtocol_proto_rawDescData = file_ReconfigurationProtocol_proto_rawDesc
)

func file_ReconfigurationProtocol_proto_rawDescGZIP() []byte {
	file_ReconfigurationProtocol_proto_rawDescOnce.Do(func() {
		file_ReconfigurationProtocol_proto_rawDescData = protoimpl.X.CompressGZIP(file_ReconfigurationProtocol_proto_rawDescData)
	})
	return file_ReconfigurationProtocol_proto_rawDescData
}

var file_ReconfigurationProtocol_proto_msgTypes = make([]protoimpl.MessageInfo, 7)
var file_ReconfigurationProtocol_proto_goTypes = []interface{}{
	(*StartReconfigurationRequestProto)(nil),          // 0: hadoop.hdfs.StartReconfigurationRequestProto
	(*StartReconfigurationResponseProto)(nil),         // 1: hadoop.hdfs.StartReconfigurationResponseProto
	(*GetReconfigurationStatusRequestProto)(nil),      // 2: hadoop.hdfs.GetReconfigurationStatusRequestProto
	(*GetReconfigurationStatusConfigChangeProto)(nil), // 3: hadoop.hdfs.GetReconfigurationStatusConfigChangeProto
	(*GetReconfigurationStatusResponseProto)(nil),     // 4: hadoop.hdfs.GetReconfigurationStatusResponseProto
	(*ListReconfigurablePropertiesRequestProto)(nil),  // 5: hadoop.hdfs.ListReconfigurablePropertiesRequestProto
	(*ListReconfigurablePropertiesResponseProto)(nil), // 6: hadoop.hdfs.ListReconfigurablePropertiesResponseProto
}
var file_ReconfigurationProtocol_proto_depIdxs = []int32{
	3, // 0: hadoop.hdfs.GetReconfigurationStatusResponseProto.changes:type_name -> hadoop.hdfs.GetReconfigurationStatusConfigChangeProto
	2, // 1: hadoop.hdfs.ReconfigurationProtocolService.getReconfigurationStatus:input_type -> hadoop.hdfs.GetReconfigurationStatusRequestProto
	0, // 2: hadoop.hdfs.ReconfigurationProtocolService.startReconfiguration:input_type -> hadoop.hdfs.StartReconfigurationRequestProto
	5, // 3: hadoop.hdfs.ReconfigurationProtocolService.listReconfigurableProperties:input_type -> hadoop.hdfs.ListReconfigurablePropertiesRequestProto
	4, // 4: hadoop.hdfs.ReconfigurationProtocolService.getReconfigurationStatus:output_type -> hadoop.hdfs.GetReconfigurationStatusResponseProto
	1, // 5: hadoop.hdfs.ReconfigurationProtocolService.startReconfiguration:output_type -> hadoop.hdfs.StartReconfigurationResponseProto
	6, // 6: hadoop.hdfs.ReconfigurationProtocolService.listReconfigurableProperties:output_type -> hadoop.hdfs.ListReconfigurablePropertiesResponseProto
	4, // [4:7] is the sub-list for method output_type
	1, // [1:4] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_ReconfigurationProtocol_proto_init() }
func file_ReconfigurationProtocol_proto_init() {
	if File_ReconfigurationProtocol_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_ReconfigurationProtocol_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*StartReconfigurationRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_ReconfigurationProtocol_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*StartReconfigurationResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_ReconfigurationProtocol_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetReconfigurationStatusRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_ReconfigurationProtocol_proto_msgTypes[3].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetReconfigurationStatusConfigChangeProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_ReconfigurationProtocol_proto_msgTypes[4].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetReconfigurationStatusResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_ReconfigurationProtocol_proto_msgTypes[5].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ListReconfigurablePropertiesRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_ReconfigurationProtocol_proto_msgTypes[6].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ListReconfigurablePropertiesResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_ReconfigurationProtocol_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   7,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_ReconfigurationProtocol_proto_goTypes,
		DependencyIndexes: file_ReconfigurationProtocol_proto_depIdxs,
		MessageInfos:      file_ReconfigurationProtocol_proto_msgTypes,
	}.Build()
	File_ReconfigurationProtocol_proto = out.File
	file_ReconfigurationProtocol_proto_rawDesc = nil
	file_ReconfigurationProtocol_proto_goTypes = nil
	file_ReconfigurationProtocol_proto_depIdxs = nil
}
