//*
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.27.1
// 	protoc        v3.19.4
// source: acl.proto

package hadoop_hdfs

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type AclEntryProto_AclEntryScopeProto int32

const (
	AclEntryProto_ACCESS  AclEntryProto_AclEntryScopeProto = 0
	AclEntryProto_DEFAULT AclEntryProto_AclEntryScopeProto = 1
)

// Enum value maps for AclEntryProto_AclEntryScopeProto.
var (
	AclEntryProto_AclEntryScopeProto_name = map[int32]string{
		0: "ACCESS",
		1: "DEFAULT",
	}
	AclEntryProto_AclEntryScopeProto_value = map[string]int32{
		"ACCESS":  0,
		"DEFAULT": 1,
	}
)

func (x AclEntryProto_AclEntryScopeProto) Enum() *AclEntryProto_AclEntryScopeProto {
	p := new(AclEntryProto_AclEntryScopeProto)
	*p = x
	return p
}

func (x AclEntryProto_AclEntryScopeProto) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (AclEntryProto_AclEntryScopeProto) Descriptor() protoreflect.EnumDescriptor {
	return file_acl_proto_enumTypes[0].Descriptor()
}

func (AclEntryProto_AclEntryScopeProto) Type() protoreflect.EnumType {
	return &file_acl_proto_enumTypes[0]
}

func (x AclEntryProto_AclEntryScopeProto) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Do not use.
func (x *AclEntryProto_AclEntryScopeProto) UnmarshalJSON(b []byte) error {
	num, err := protoimpl.X.UnmarshalJSONEnum(x.Descriptor(), b)
	if err != nil {
		return err
	}
	*x = AclEntryProto_AclEntryScopeProto(num)
	return nil
}

// Deprecated: Use AclEntryProto_AclEntryScopeProto.Descriptor instead.
func (AclEntryProto_AclEntryScopeProto) EnumDescriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{1, 0}
}

type AclEntryProto_AclEntryTypeProto int32

const (
	AclEntryProto_USER  AclEntryProto_AclEntryTypeProto = 0
	AclEntryProto_GROUP AclEntryProto_AclEntryTypeProto = 1
	AclEntryProto_MASK  AclEntryProto_AclEntryTypeProto = 2
	AclEntryProto_OTHER AclEntryProto_AclEntryTypeProto = 3
)

// Enum value maps for AclEntryProto_AclEntryTypeProto.
var (
	AclEntryProto_AclEntryTypeProto_name = map[int32]string{
		0: "USER",
		1: "GROUP",
		2: "MASK",
		3: "OTHER",
	}
	AclEntryProto_AclEntryTypeProto_value = map[string]int32{
		"USER":  0,
		"GROUP": 1,
		"MASK":  2,
		"OTHER": 3,
	}
)

func (x AclEntryProto_AclEntryTypeProto) Enum() *AclEntryProto_AclEntryTypeProto {
	p := new(AclEntryProto_AclEntryTypeProto)
	*p = x
	return p
}

func (x AclEntryProto_AclEntryTypeProto) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (AclEntryProto_AclEntryTypeProto) Descriptor() protoreflect.EnumDescriptor {
	return file_acl_proto_enumTypes[1].Descriptor()
}

func (AclEntryProto_AclEntryTypeProto) Type() protoreflect.EnumType {
	return &file_acl_proto_enumTypes[1]
}

func (x AclEntryProto_AclEntryTypeProto) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Do not use.
func (x *AclEntryProto_AclEntryTypeProto) UnmarshalJSON(b []byte) error {
	num, err := protoimpl.X.UnmarshalJSONEnum(x.Descriptor(), b)
	if err != nil {
		return err
	}
	*x = AclEntryProto_AclEntryTypeProto(num)
	return nil
}

// Deprecated: Use AclEntryProto_AclEntryTypeProto.Descriptor instead.
func (AclEntryProto_AclEntryTypeProto) EnumDescriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{1, 1}
}

type AclEntryProto_FsActionProto int32

const (
	AclEntryProto_NONE          AclEntryProto_FsActionProto = 0
	AclEntryProto_EXECUTE       AclEntryProto_FsActionProto = 1
	AclEntryProto_WRITE         AclEntryProto_FsActionProto = 2
	AclEntryProto_WRITE_EXECUTE AclEntryProto_FsActionProto = 3
	AclEntryProto_READ          AclEntryProto_FsActionProto = 4
	AclEntryProto_READ_EXECUTE  AclEntryProto_FsActionProto = 5
	AclEntryProto_READ_WRITE    AclEntryProto_FsActionProto = 6
	AclEntryProto_PERM_ALL      AclEntryProto_FsActionProto = 7
)

// Enum value maps for AclEntryProto_FsActionProto.
var (
	AclEntryProto_FsActionProto_name = map[int32]string{
		0: "NONE",
		1: "EXECUTE",
		2: "WRITE",
		3: "WRITE_EXECUTE",
		4: "READ",
		5: "READ_EXECUTE",
		6: "READ_WRITE",
		7: "PERM_ALL",
	}
	AclEntryProto_FsActionProto_value = map[string]int32{
		"NONE":          0,
		"EXECUTE":       1,
		"WRITE":         2,
		"WRITE_EXECUTE": 3,
		"READ":          4,
		"READ_EXECUTE":  5,
		"READ_WRITE":    6,
		"PERM_ALL":      7,
	}
)

func (x AclEntryProto_FsActionProto) Enum() *AclEntryProto_FsActionProto {
	p := new(AclEntryProto_FsActionProto)
	*p = x
	return p
}

func (x AclEntryProto_FsActionProto) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (AclEntryProto_FsActionProto) Descriptor() protoreflect.EnumDescriptor {
	return file_acl_proto_enumTypes[2].Descriptor()
}

func (AclEntryProto_FsActionProto) Type() protoreflect.EnumType {
	return &file_acl_proto_enumTypes[2]
}

func (x AclEntryProto_FsActionProto) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Do not use.
func (x *AclEntryProto_FsActionProto) UnmarshalJSON(b []byte) error {
	num, err := protoimpl.X.UnmarshalJSONEnum(x.Descriptor(), b)
	if err != nil {
		return err
	}
	*x = AclEntryProto_FsActionProto(num)
	return nil
}

// Deprecated: Use AclEntryProto_FsActionProto.Descriptor instead.
func (AclEntryProto_FsActionProto) EnumDescriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{1, 2}
}

//*
// File or Directory permision - same spec as posix
type FsPermissionProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Perm *uint32 `protobuf:"varint,1,req,name=perm" json:"perm,omitempty"` // Actually a short - only 16bits used
}

func (x *FsPermissionProto) Reset() {
	*x = FsPermissionProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *FsPermissionProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*FsPermissionProto) ProtoMessage() {}

func (x *FsPermissionProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use FsPermissionProto.ProtoReflect.Descriptor instead.
func (*FsPermissionProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{0}
}

func (x *FsPermissionProto) GetPerm() uint32 {
	if x != nil && x.Perm != nil {
		return *x.Perm
	}
	return 0
}

type AclEntryProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Type        *AclEntryProto_AclEntryTypeProto  `protobuf:"varint,1,req,name=type,enum=hadoop.hdfs.AclEntryProto_AclEntryTypeProto" json:"type,omitempty"`
	Scope       *AclEntryProto_AclEntryScopeProto `protobuf:"varint,2,req,name=scope,enum=hadoop.hdfs.AclEntryProto_AclEntryScopeProto" json:"scope,omitempty"`
	Permissions *AclEntryProto_FsActionProto      `protobuf:"varint,3,req,name=permissions,enum=hadoop.hdfs.AclEntryProto_FsActionProto" json:"permissions,omitempty"`
	Name        *string                           `protobuf:"bytes,4,opt,name=name" json:"name,omitempty"`
}

func (x *AclEntryProto) Reset() {
	*x = AclEntryProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[1]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AclEntryProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AclEntryProto) ProtoMessage() {}

func (x *AclEntryProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[1]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AclEntryProto.ProtoReflect.Descriptor instead.
func (*AclEntryProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{1}
}

func (x *AclEntryProto) GetType() AclEntryProto_AclEntryTypeProto {
	if x != nil && x.Type != nil {
		return *x.Type
	}
	return AclEntryProto_USER
}

func (x *AclEntryProto) GetScope() AclEntryProto_AclEntryScopeProto {
	if x != nil && x.Scope != nil {
		return *x.Scope
	}
	return AclEntryProto_ACCESS
}

func (x *AclEntryProto) GetPermissions() AclEntryProto_FsActionProto {
	if x != nil && x.Permissions != nil {
		return *x.Permissions
	}
	return AclEntryProto_NONE
}

func (x *AclEntryProto) GetName() string {
	if x != nil && x.Name != nil {
		return *x.Name
	}
	return ""
}

type AclStatusProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Owner      *string            `protobuf:"bytes,1,req,name=owner" json:"owner,omitempty"`
	Group      *string            `protobuf:"bytes,2,req,name=group" json:"group,omitempty"`
	Sticky     *bool              `protobuf:"varint,3,req,name=sticky" json:"sticky,omitempty"`
	Entries    []*AclEntryProto   `protobuf:"bytes,4,rep,name=entries" json:"entries,omitempty"`
	Permission *FsPermissionProto `protobuf:"bytes,5,opt,name=permission" json:"permission,omitempty"`
}

func (x *AclStatusProto) Reset() {
	*x = AclStatusProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[2]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *AclStatusProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AclStatusProto) ProtoMessage() {}

func (x *AclStatusProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[2]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AclStatusProto.ProtoReflect.Descriptor instead.
func (*AclStatusProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{2}
}

func (x *AclStatusProto) GetOwner() string {
	if x != nil && x.Owner != nil {
		return *x.Owner
	}
	return ""
}

func (x *AclStatusProto) GetGroup() string {
	if x != nil && x.Group != nil {
		return *x.Group
	}
	return ""
}

func (x *AclStatusProto) GetSticky() bool {
	if x != nil && x.Sticky != nil {
		return *x.Sticky
	}
	return false
}

func (x *AclStatusProto) GetEntries() []*AclEntryProto {
	if x != nil {
		return x.Entries
	}
	return nil
}

func (x *AclStatusProto) GetPermission() *FsPermissionProto {
	if x != nil {
		return x.Permission
	}
	return nil
}

type ModifyAclEntriesRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src     *string          `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
	AclSpec []*AclEntryProto `protobuf:"bytes,2,rep,name=aclSpec" json:"aclSpec,omitempty"`
}

func (x *ModifyAclEntriesRequestProto) Reset() {
	*x = ModifyAclEntriesRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[3]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ModifyAclEntriesRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ModifyAclEntriesRequestProto) ProtoMessage() {}

func (x *ModifyAclEntriesRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[3]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ModifyAclEntriesRequestProto.ProtoReflect.Descriptor instead.
func (*ModifyAclEntriesRequestProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{3}
}

func (x *ModifyAclEntriesRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

func (x *ModifyAclEntriesRequestProto) GetAclSpec() []*AclEntryProto {
	if x != nil {
		return x.AclSpec
	}
	return nil
}

type ModifyAclEntriesResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *ModifyAclEntriesResponseProto) Reset() {
	*x = ModifyAclEntriesResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[4]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ModifyAclEntriesResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ModifyAclEntriesResponseProto) ProtoMessage() {}

func (x *ModifyAclEntriesResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[4]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ModifyAclEntriesResponseProto.ProtoReflect.Descriptor instead.
func (*ModifyAclEntriesResponseProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{4}
}

type RemoveAclRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src *string `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
}

func (x *RemoveAclRequestProto) Reset() {
	*x = RemoveAclRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[5]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveAclRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveAclRequestProto) ProtoMessage() {}

func (x *RemoveAclRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[5]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveAclRequestProto.ProtoReflect.Descriptor instead.
func (*RemoveAclRequestProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{5}
}

func (x *RemoveAclRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

type RemoveAclResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *RemoveAclResponseProto) Reset() {
	*x = RemoveAclResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[6]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveAclResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveAclResponseProto) ProtoMessage() {}

func (x *RemoveAclResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[6]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveAclResponseProto.ProtoReflect.Descriptor instead.
func (*RemoveAclResponseProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{6}
}

type RemoveAclEntriesRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src     *string          `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
	AclSpec []*AclEntryProto `protobuf:"bytes,2,rep,name=aclSpec" json:"aclSpec,omitempty"`
}

func (x *RemoveAclEntriesRequestProto) Reset() {
	*x = RemoveAclEntriesRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[7]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveAclEntriesRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveAclEntriesRequestProto) ProtoMessage() {}

func (x *RemoveAclEntriesRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[7]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveAclEntriesRequestProto.ProtoReflect.Descriptor instead.
func (*RemoveAclEntriesRequestProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{7}
}

func (x *RemoveAclEntriesRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

func (x *RemoveAclEntriesRequestProto) GetAclSpec() []*AclEntryProto {
	if x != nil {
		return x.AclSpec
	}
	return nil
}

type RemoveAclEntriesResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *RemoveAclEntriesResponseProto) Reset() {
	*x = RemoveAclEntriesResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[8]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveAclEntriesResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveAclEntriesResponseProto) ProtoMessage() {}

func (x *RemoveAclEntriesResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[8]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveAclEntriesResponseProto.ProtoReflect.Descriptor instead.
func (*RemoveAclEntriesResponseProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{8}
}

type RemoveDefaultAclRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src *string `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
}

func (x *RemoveDefaultAclRequestProto) Reset() {
	*x = RemoveDefaultAclRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[9]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveDefaultAclRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveDefaultAclRequestProto) ProtoMessage() {}

func (x *RemoveDefaultAclRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[9]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveDefaultAclRequestProto.ProtoReflect.Descriptor instead.
func (*RemoveDefaultAclRequestProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{9}
}

func (x *RemoveDefaultAclRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

type RemoveDefaultAclResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *RemoveDefaultAclResponseProto) Reset() {
	*x = RemoveDefaultAclResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[10]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *RemoveDefaultAclResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RemoveDefaultAclResponseProto) ProtoMessage() {}

func (x *RemoveDefaultAclResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[10]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RemoveDefaultAclResponseProto.ProtoReflect.Descriptor instead.
func (*RemoveDefaultAclResponseProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{10}
}

type SetAclRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src     *string          `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
	AclSpec []*AclEntryProto `protobuf:"bytes,2,rep,name=aclSpec" json:"aclSpec,omitempty"`
}

func (x *SetAclRequestProto) Reset() {
	*x = SetAclRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[11]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *SetAclRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SetAclRequestProto) ProtoMessage() {}

func (x *SetAclRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[11]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SetAclRequestProto.ProtoReflect.Descriptor instead.
func (*SetAclRequestProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{11}
}

func (x *SetAclRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

func (x *SetAclRequestProto) GetAclSpec() []*AclEntryProto {
	if x != nil {
		return x.AclSpec
	}
	return nil
}

type SetAclResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields
}

func (x *SetAclResponseProto) Reset() {
	*x = SetAclResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[12]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *SetAclResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SetAclResponseProto) ProtoMessage() {}

func (x *SetAclResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[12]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SetAclResponseProto.ProtoReflect.Descriptor instead.
func (*SetAclResponseProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{12}
}

type GetAclStatusRequestProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Src *string `protobuf:"bytes,1,req,name=src" json:"src,omitempty"`
}

func (x *GetAclStatusRequestProto) Reset() {
	*x = GetAclStatusRequestProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[13]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetAclStatusRequestProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetAclStatusRequestProto) ProtoMessage() {}

func (x *GetAclStatusRequestProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[13]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetAclStatusRequestProto.ProtoReflect.Descriptor instead.
func (*GetAclStatusRequestProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{13}
}

func (x *GetAclStatusRequestProto) GetSrc() string {
	if x != nil && x.Src != nil {
		return *x.Src
	}
	return ""
}

type GetAclStatusResponseProto struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	Result *AclStatusProto `protobuf:"bytes,1,req,name=result" json:"result,omitempty"`
}

func (x *GetAclStatusResponseProto) Reset() {
	*x = GetAclStatusResponseProto{}
	if protoimpl.UnsafeEnabled {
		mi := &file_acl_proto_msgTypes[14]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GetAclStatusResponseProto) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetAclStatusResponseProto) ProtoMessage() {}

func (x *GetAclStatusResponseProto) ProtoReflect() protoreflect.Message {
	mi := &file_acl_proto_msgTypes[14]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetAclStatusResponseProto.ProtoReflect.Descriptor instead.
func (*GetAclStatusResponseProto) Descriptor() ([]byte, []int) {
	return file_acl_proto_rawDescGZIP(), []int{14}
}

func (x *GetAclStatusResponseProto) GetResult() *AclStatusProto {
	if x != nil {
		return x.Result
	}
	return nil
}

var File_acl_proto protoreflect.FileDescriptor

var file_acl_proto_rawDesc = []byte{
	0x0a, 0x09, 0x61, 0x63, 0x6c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x0b, 0x68, 0x61, 0x64,
	0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x22, 0x27, 0x0a, 0x11, 0x46, 0x73, 0x50, 0x65,
	0x72, 0x6d, 0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x12, 0x0a,
	0x04, 0x70, 0x65, 0x72, 0x6d, 0x18, 0x01, 0x20, 0x02, 0x28, 0x0d, 0x52, 0x04, 0x70, 0x65, 0x72,
	0x6d, 0x22, 0xe4, 0x03, 0x0a, 0x0d, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50, 0x72,
	0x6f, 0x74, 0x6f, 0x12, 0x40, 0x0a, 0x04, 0x74, 0x79, 0x70, 0x65, 0x18, 0x01, 0x20, 0x02, 0x28,
	0x0e, 0x32, 0x2c, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e,
	0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x41, 0x63,
	0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x54, 0x79, 0x70, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52,
	0x04, 0x74, 0x79, 0x70, 0x65, 0x12, 0x43, 0x0a, 0x05, 0x73, 0x63, 0x6f, 0x70, 0x65, 0x18, 0x02,
	0x20, 0x02, 0x28, 0x0e, 0x32, 0x2d, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64,
	0x66, 0x73, 0x2e, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f,
	0x2e, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x53, 0x63, 0x6f, 0x70, 0x65, 0x50, 0x72,
	0x6f, 0x74, 0x6f, 0x52, 0x05, 0x73, 0x63, 0x6f, 0x70, 0x65, 0x12, 0x4a, 0x0a, 0x0b, 0x70, 0x65,
	0x72, 0x6d, 0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x18, 0x03, 0x20, 0x02, 0x28, 0x0e, 0x32,
	0x28, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x41, 0x63,
	0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x2e, 0x46, 0x73, 0x41, 0x63,
	0x74, 0x69, 0x6f, 0x6e, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x0b, 0x70, 0x65, 0x72, 0x6d, 0x69,
	0x73, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x12, 0x12, 0x0a, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x18, 0x04,
	0x20, 0x01, 0x28, 0x09, 0x52, 0x04, 0x6e, 0x61, 0x6d, 0x65, 0x22, 0x2d, 0x0a, 0x12, 0x41, 0x63,
	0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x53, 0x63, 0x6f, 0x70, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f,
	0x12, 0x0a, 0x0a, 0x06, 0x41, 0x43, 0x43, 0x45, 0x53, 0x53, 0x10, 0x00, 0x12, 0x0b, 0x0a, 0x07,
	0x44, 0x45, 0x46, 0x41, 0x55, 0x4c, 0x54, 0x10, 0x01, 0x22, 0x3d, 0x0a, 0x11, 0x41, 0x63, 0x6c,
	0x45, 0x6e, 0x74, 0x72, 0x79, 0x54, 0x79, 0x70, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x08,
	0x0a, 0x04, 0x55, 0x53, 0x45, 0x52, 0x10, 0x00, 0x12, 0x09, 0x0a, 0x05, 0x47, 0x52, 0x4f, 0x55,
	0x50, 0x10, 0x01, 0x12, 0x08, 0x0a, 0x04, 0x4d, 0x41, 0x53, 0x4b, 0x10, 0x02, 0x12, 0x09, 0x0a,
	0x05, 0x4f, 0x54, 0x48, 0x45, 0x52, 0x10, 0x03, 0x22, 0x7e, 0x0a, 0x0d, 0x46, 0x73, 0x41, 0x63,
	0x74, 0x69, 0x6f, 0x6e, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x08, 0x0a, 0x04, 0x4e, 0x4f, 0x4e,
	0x45, 0x10, 0x00, 0x12, 0x0b, 0x0a, 0x07, 0x45, 0x58, 0x45, 0x43, 0x55, 0x54, 0x45, 0x10, 0x01,
	0x12, 0x09, 0x0a, 0x05, 0x57, 0x52, 0x49, 0x54, 0x45, 0x10, 0x02, 0x12, 0x11, 0x0a, 0x0d, 0x57,
	0x52, 0x49, 0x54, 0x45, 0x5f, 0x45, 0x58, 0x45, 0x43, 0x55, 0x54, 0x45, 0x10, 0x03, 0x12, 0x08,
	0x0a, 0x04, 0x52, 0x45, 0x41, 0x44, 0x10, 0x04, 0x12, 0x10, 0x0a, 0x0c, 0x52, 0x45, 0x41, 0x44,
	0x5f, 0x45, 0x58, 0x45, 0x43, 0x55, 0x54, 0x45, 0x10, 0x05, 0x12, 0x0e, 0x0a, 0x0a, 0x52, 0x45,
	0x41, 0x44, 0x5f, 0x57, 0x52, 0x49, 0x54, 0x45, 0x10, 0x06, 0x12, 0x0c, 0x0a, 0x08, 0x50, 0x45,
	0x52, 0x4d, 0x5f, 0x41, 0x4c, 0x4c, 0x10, 0x07, 0x22, 0xca, 0x01, 0x0a, 0x0e, 0x41, 0x63, 0x6c,
	0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x14, 0x0a, 0x05, 0x6f,
	0x77, 0x6e, 0x65, 0x72, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x05, 0x6f, 0x77, 0x6e, 0x65,
	0x72, 0x12, 0x14, 0x0a, 0x05, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x18, 0x02, 0x20, 0x02, 0x28, 0x09,
	0x52, 0x05, 0x67, 0x72, 0x6f, 0x75, 0x70, 0x12, 0x16, 0x0a, 0x06, 0x73, 0x74, 0x69, 0x63, 0x6b,
	0x79, 0x18, 0x03, 0x20, 0x02, 0x28, 0x08, 0x52, 0x06, 0x73, 0x74, 0x69, 0x63, 0x6b, 0x79, 0x12,
	0x34, 0x0a, 0x07, 0x65, 0x6e, 0x74, 0x72, 0x69, 0x65, 0x73, 0x18, 0x04, 0x20, 0x03, 0x28, 0x0b,
	0x32, 0x1a, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x41,
	0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x07, 0x65, 0x6e,
	0x74, 0x72, 0x69, 0x65, 0x73, 0x12, 0x3e, 0x0a, 0x0a, 0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 0x73,
	0x69, 0x6f, 0x6e, 0x18, 0x05, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x1e, 0x2e, 0x68, 0x61, 0x64, 0x6f,
	0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x46, 0x73, 0x50, 0x65, 0x72, 0x6d, 0x69, 0x73,
	0x73, 0x69, 0x6f, 0x6e, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x0a, 0x70, 0x65, 0x72, 0x6d, 0x69,
	0x73, 0x73, 0x69, 0x6f, 0x6e, 0x22, 0x66, 0x0a, 0x1c, 0x4d, 0x6f, 0x64, 0x69, 0x66, 0x79, 0x41,
	0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x69, 0x65, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74,
	0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x02,
	0x28, 0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x12, 0x34, 0x0a, 0x07, 0x61, 0x63, 0x6c, 0x53, 0x70,
	0x65, 0x63, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f,
	0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x52, 0x07, 0x61, 0x63, 0x6c, 0x53, 0x70, 0x65, 0x63, 0x22, 0x1f, 0x0a,
	0x1d, 0x4d, 0x6f, 0x64, 0x69, 0x66, 0x79, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x69, 0x65,
	0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x29,
	0x0a, 0x15, 0x52, 0x65, 0x6d, 0x6f, 0x76, 0x65, 0x41, 0x63, 0x6c, 0x52, 0x65, 0x71, 0x75, 0x65,
	0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01,
	0x20, 0x02, 0x28, 0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x22, 0x18, 0x0a, 0x16, 0x52, 0x65, 0x6d,
	0x6f, 0x76, 0x65, 0x41, 0x63, 0x6c, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72,
	0x6f, 0x74, 0x6f, 0x22, 0x66, 0x0a, 0x1c, 0x52, 0x65, 0x6d, 0x6f, 0x76, 0x65, 0x41, 0x63, 0x6c,
	0x45, 0x6e, 0x74, 0x72, 0x69, 0x65, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72,
	0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09,
	0x52, 0x03, 0x73, 0x72, 0x63, 0x12, 0x34, 0x0a, 0x07, 0x61, 0x63, 0x6c, 0x53, 0x70, 0x65, 0x63,
	0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e,
	0x68, 0x64, 0x66, 0x73, 0x2e, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50, 0x72, 0x6f,
	0x74, 0x6f, 0x52, 0x07, 0x61, 0x63, 0x6c, 0x53, 0x70, 0x65, 0x63, 0x22, 0x1f, 0x0a, 0x1d, 0x52,
	0x65, 0x6d, 0x6f, 0x76, 0x65, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x69, 0x65, 0x73, 0x52,
	0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x30, 0x0a, 0x1c,
	0x52, 0x65, 0x6d, 0x6f, 0x76, 0x65, 0x44, 0x65, 0x66, 0x61, 0x75, 0x6c, 0x74, 0x41, 0x63, 0x6c,
	0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03,
	0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x22, 0x1f,
	0x0a, 0x1d, 0x52, 0x65, 0x6d, 0x6f, 0x76, 0x65, 0x44, 0x65, 0x66, 0x61, 0x75, 0x6c, 0x74, 0x41,
	0x63, 0x6c, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x22,
	0x5c, 0x0a, 0x12, 0x53, 0x65, 0x74, 0x41, 0x63, 0x6c, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74,
	0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x02,
	0x28, 0x09, 0x52, 0x03, 0x73, 0x72, 0x63, 0x12, 0x34, 0x0a, 0x07, 0x61, 0x63, 0x6c, 0x53, 0x70,
	0x65, 0x63, 0x18, 0x02, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x1a, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f,
	0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x41, 0x63, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x52, 0x07, 0x61, 0x63, 0x6c, 0x53, 0x70, 0x65, 0x63, 0x22, 0x15, 0x0a,
	0x13, 0x53, 0x65, 0x74, 0x41, 0x63, 0x6c, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x22, 0x2c, 0x0a, 0x18, 0x47, 0x65, 0x74, 0x41, 0x63, 0x6c, 0x53, 0x74,
	0x61, 0x74, 0x75, 0x73, 0x52, 0x65, 0x71, 0x75, 0x65, 0x73, 0x74, 0x50, 0x72, 0x6f, 0x74, 0x6f,
	0x12, 0x10, 0x0a, 0x03, 0x73, 0x72, 0x63, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x03, 0x73,
	0x72, 0x63, 0x22, 0x50, 0x0a, 0x19, 0x47, 0x65, 0x74, 0x41, 0x63, 0x6c, 0x53, 0x74, 0x61, 0x74,
	0x75, 0x73, 0x52, 0x65, 0x73, 0x70, 0x6f, 0x6e, 0x73, 0x65, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x12,
	0x33, 0x0a, 0x06, 0x72, 0x65, 0x73, 0x75, 0x6c, 0x74, 0x18, 0x01, 0x20, 0x02, 0x28, 0x0b, 0x32,
	0x1b, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x41, 0x63,
	0x6c, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x52, 0x06, 0x72, 0x65,
	0x73, 0x75, 0x6c, 0x74, 0x42, 0x71, 0x0a, 0x25, 0x6f, 0x72, 0x67, 0x2e, 0x61, 0x70, 0x61, 0x63,
	0x68, 0x65, 0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x70,
	0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x42, 0x09, 0x41,
	0x63, 0x6c, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x73, 0x5a, 0x3a, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62,
	0x2e, 0x63, 0x6f, 0x6d, 0x2f, 0x63, 0x6f, 0x6c, 0x69, 0x6e, 0x6d, 0x61, 0x72, 0x63, 0x2f, 0x68,
	0x64, 0x66, 0x73, 0x2f, 0x76, 0x32, 0x2f, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2f,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2f, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x5f,
	0x68, 0x64, 0x66, 0x73, 0xa0, 0x01, 0x01,
}

var (
	file_acl_proto_rawDescOnce sync.Once
	file_acl_proto_rawDescData = file_acl_proto_rawDesc
)

func file_acl_proto_rawDescGZIP() []byte {
	file_acl_proto_rawDescOnce.Do(func() {
		file_acl_proto_rawDescData = protoimpl.X.CompressGZIP(file_acl_proto_rawDescData)
	})
	return file_acl_proto_rawDescData
}

var file_acl_proto_enumTypes = make([]protoimpl.EnumInfo, 3)
var file_acl_proto_msgTypes = make([]protoimpl.MessageInfo, 15)
var file_acl_proto_goTypes = []interface{}{
	(AclEntryProto_AclEntryScopeProto)(0), // 0: hadoop.hdfs.AclEntryProto.AclEntryScopeProto
	(AclEntryProto_AclEntryTypeProto)(0),  // 1: hadoop.hdfs.AclEntryProto.AclEntryTypeProto
	(AclEntryProto_FsActionProto)(0),      // 2: hadoop.hdfs.AclEntryProto.FsActionProto
	(*FsPermissionProto)(nil),             // 3: hadoop.hdfs.FsPermissionProto
	(*AclEntryProto)(nil),                 // 4: hadoop.hdfs.AclEntryProto
	(*AclStatusProto)(nil),                // 5: hadoop.hdfs.AclStatusProto
	(*ModifyAclEntriesRequestProto)(nil),  // 6: hadoop.hdfs.ModifyAclEntriesRequestProto
	(*ModifyAclEntriesResponseProto)(nil), // 7: hadoop.hdfs.ModifyAclEntriesResponseProto
	(*RemoveAclRequestProto)(nil),         // 8: hadoop.hdfs.RemoveAclRequestProto
	(*RemoveAclResponseProto)(nil),        // 9: hadoop.hdfs.RemoveAclResponseProto
	(*RemoveAclEntriesRequestProto)(nil),  // 10: hadoop.hdfs.RemoveAclEntriesRequestProto
	(*RemoveAclEntriesResponseProto)(nil), // 11: hadoop.hdfs.RemoveAclEntriesResponseProto
	(*RemoveDefaultAclRequestProto)(nil),  // 12: hadoop.hdfs.RemoveDefaultAclRequestProto
	(*RemoveDefaultAclResponseProto)(nil), // 13: hadoop.hdfs.RemoveDefaultAclResponseProto
	(*SetAclRequestProto)(nil),            // 14: hadoop.hdfs.SetAclRequestProto
	(*SetAclResponseProto)(nil),           // 15: hadoop.hdfs.SetAclResponseProto
	(*GetAclStatusRequestProto)(nil),      // 16: hadoop.hdfs.GetAclStatusRequestProto
	(*GetAclStatusResponseProto)(nil),     // 17: hadoop.hdfs.GetAclStatusResponseProto
}
var file_acl_proto_depIdxs = []int32{
	1, // 0: hadoop.hdfs.AclEntryProto.type:type_name -> hadoop.hdfs.AclEntryProto.AclEntryTypeProto
	0, // 1: hadoop.hdfs.AclEntryProto.scope:type_name -> hadoop.hdfs.AclEntryProto.AclEntryScopeProto
	2, // 2: hadoop.hdfs.AclEntryProto.permissions:type_name -> hadoop.hdfs.AclEntryProto.FsActionProto
	4, // 3: hadoop.hdfs.AclStatusProto.entries:type_name -> hadoop.hdfs.AclEntryProto
	3, // 4: hadoop.hdfs.AclStatusProto.permission:type_name -> hadoop.hdfs.FsPermissionProto
	4, // 5: hadoop.hdfs.ModifyAclEntriesRequestProto.aclSpec:type_name -> hadoop.hdfs.AclEntryProto
	4, // 6: hadoop.hdfs.RemoveAclEntriesRequestProto.aclSpec:type_name -> hadoop.hdfs.AclEntryProto
	4, // 7: hadoop.hdfs.SetAclRequestProto.aclSpec:type_name -> hadoop.hdfs.AclEntryProto
	5, // 8: hadoop.hdfs.GetAclStatusResponseProto.result:type_name -> hadoop.hdfs.AclStatusProto
	9, // [9:9] is the sub-list for method output_type
	9, // [9:9] is the sub-list for method input_type
	9, // [9:9] is the sub-list for extension type_name
	9, // [9:9] is the sub-list for extension extendee
	0, // [0:9] is the sub-list for field type_name
}

func init() { file_acl_proto_init() }
func file_acl_proto_init() {
	if File_acl_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_acl_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*FsPermissionProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[1].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AclEntryProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[2].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*AclStatusProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[3].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ModifyAclEntriesRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[4].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ModifyAclEntriesResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[5].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveAclRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[6].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveAclResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[7].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveAclEntriesRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[8].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveAclEntriesResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[9].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveDefaultAclRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[10].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*RemoveDefaultAclResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[11].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*SetAclRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[12].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*SetAclResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[13].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetAclStatusRequestProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
		file_acl_proto_msgTypes[14].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GetAclStatusResponseProto); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_acl_proto_rawDesc,
			NumEnums:      3,
			NumMessages:   15,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_acl_proto_goTypes,
		DependencyIndexes: file_acl_proto_depIdxs,
		EnumInfos:         file_acl_proto_enumTypes,
		MessageInfos:      file_acl_proto_msgTypes,
	}.Build()
	File_acl_proto = out.File
	file_acl_proto_rawDesc = nil
	file_acl_proto_goTypes = nil
	file_acl_proto_depIdxs = nil
}
