//*
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//*
// These .proto interfaces are private and stable.
// Please see http://wiki.apache.org/hadoop/Compatibility
// for what changes are allowed for a *stable* .proto interface.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.27.1
// 	protoc        v3.19.4
// source: HAZKInfo.proto

package hadoop_hdfs

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type ActiveNodeInfo struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	NameserviceId *string `protobuf:"bytes,1,req,name=nameserviceId" json:"nameserviceId,omitempty"`
	NamenodeId    *string `protobuf:"bytes,2,req,name=namenodeId" json:"namenodeId,omitempty"`
	Hostname      *string `protobuf:"bytes,3,req,name=hostname" json:"hostname,omitempty"`
	Port          *int32  `protobuf:"varint,4,req,name=port" json:"port,omitempty"`
	ZkfcPort      *int32  `protobuf:"varint,5,req,name=zkfcPort" json:"zkfcPort,omitempty"`
}

func (x *ActiveNodeInfo) Reset() {
	*x = ActiveNodeInfo{}
	if protoimpl.UnsafeEnabled {
		mi := &file_HAZKInfo_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *ActiveNodeInfo) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActiveNodeInfo) ProtoMessage() {}

func (x *ActiveNodeInfo) ProtoReflect() protoreflect.Message {
	mi := &file_HAZKInfo_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActiveNodeInfo.ProtoReflect.Descriptor instead.
func (*ActiveNodeInfo) Descriptor() ([]byte, []int) {
	return file_HAZKInfo_proto_rawDescGZIP(), []int{0}
}

func (x *ActiveNodeInfo) GetNameserviceId() string {
	if x != nil && x.NameserviceId != nil {
		return *x.NameserviceId
	}
	return ""
}

func (x *ActiveNodeInfo) GetNamenodeId() string {
	if x != nil && x.NamenodeId != nil {
		return *x.NamenodeId
	}
	return ""
}

func (x *ActiveNodeInfo) GetHostname() string {
	if x != nil && x.Hostname != nil {
		return *x.Hostname
	}
	return ""
}

func (x *ActiveNodeInfo) GetPort() int32 {
	if x != nil && x.Port != nil {
		return *x.Port
	}
	return 0
}

func (x *ActiveNodeInfo) GetZkfcPort() int32 {
	if x != nil && x.ZkfcPort != nil {
		return *x.ZkfcPort
	}
	return 0
}

var File_HAZKInfo_proto protoreflect.FileDescriptor

var file_HAZKInfo_proto_rawDesc = []byte{
	0x0a, 0x0e, 0x48, 0x41, 0x5a, 0x4b, 0x49, 0x6e, 0x66, 0x6f, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x12, 0x0b, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x22, 0xa2, 0x01,
	0x0a, 0x0e, 0x41, 0x63, 0x74, 0x69, 0x76, 0x65, 0x4e, 0x6f, 0x64, 0x65, 0x49, 0x6e, 0x66, 0x6f,
	0x12, 0x24, 0x0a, 0x0d, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x65, 0x72, 0x76, 0x69, 0x63, 0x65, 0x49,
	0x64, 0x18, 0x01, 0x20, 0x02, 0x28, 0x09, 0x52, 0x0d, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x65, 0x72,
	0x76, 0x69, 0x63, 0x65, 0x49, 0x64, 0x12, 0x1e, 0x0a, 0x0a, 0x6e, 0x61, 0x6d, 0x65, 0x6e, 0x6f,
	0x64, 0x65, 0x49, 0x64, 0x18, 0x02, 0x20, 0x02, 0x28, 0x09, 0x52, 0x0a, 0x6e, 0x61, 0x6d, 0x65,
	0x6e, 0x6f, 0x64, 0x65, 0x49, 0x64, 0x12, 0x1a, 0x0a, 0x08, 0x68, 0x6f, 0x73, 0x74, 0x6e, 0x61,
	0x6d, 0x65, 0x18, 0x03, 0x20, 0x02, 0x28, 0x09, 0x52, 0x08, 0x68, 0x6f, 0x73, 0x74, 0x6e, 0x61,
	0x6d, 0x65, 0x12, 0x12, 0x0a, 0x04, 0x70, 0x6f, 0x72, 0x74, 0x18, 0x04, 0x20, 0x02, 0x28, 0x05,
	0x52, 0x04, 0x70, 0x6f, 0x72, 0x74, 0x12, 0x1a, 0x0a, 0x08, 0x7a, 0x6b, 0x66, 0x63, 0x50, 0x6f,
	0x72, 0x74, 0x18, 0x05, 0x20, 0x02, 0x28, 0x05, 0x52, 0x08, 0x7a, 0x6b, 0x66, 0x63, 0x50, 0x6f,
	0x72, 0x74, 0x42, 0x7d, 0x0a, 0x2f, 0x6f, 0x72, 0x67, 0x2e, 0x61, 0x70, 0x61, 0x63, 0x68, 0x65,
	0x2e, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x2e, 0x68, 0x64, 0x66, 0x73, 0x2e, 0x73, 0x65, 0x72,
	0x76, 0x65, 0x72, 0x2e, 0x6e, 0x61, 0x6d, 0x65, 0x6e, 0x6f, 0x64, 0x65, 0x2e, 0x68, 0x61, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x42, 0x0e, 0x48, 0x41, 0x5a, 0x4b, 0x49, 0x6e, 0x66, 0x6f, 0x50,
	0x72, 0x6f, 0x74, 0x6f, 0x73, 0x5a, 0x3a, 0x67, 0x69, 0x74, 0x68, 0x75, 0x62, 0x2e, 0x63, 0x6f,
	0x6d, 0x2f, 0x63, 0x6f, 0x6c, 0x69, 0x6e, 0x6d, 0x61, 0x72, 0x63, 0x2f, 0x68, 0x64, 0x66, 0x73,
	0x2f, 0x76, 0x32, 0x2f, 0x69, 0x6e, 0x74, 0x65, 0x72, 0x6e, 0x61, 0x6c, 0x2f, 0x70, 0x72, 0x6f,
	0x74, 0x6f, 0x63, 0x6f, 0x6c, 0x2f, 0x68, 0x61, 0x64, 0x6f, 0x6f, 0x70, 0x5f, 0x68, 0x64, 0x66,
	0x73,
}

var (
	file_HAZKInfo_proto_rawDescOnce sync.Once
	file_HAZKInfo_proto_rawDescData = file_HAZKInfo_proto_rawDesc
)

func file_HAZKInfo_proto_rawDescGZIP() []byte {
	file_HAZKInfo_proto_rawDescOnce.Do(func() {
		file_HAZKInfo_proto_rawDescData = protoimpl.X.CompressGZIP(file_HAZKInfo_proto_rawDescData)
	})
	return file_HAZKInfo_proto_rawDescData
}

var file_HAZKInfo_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_HAZKInfo_proto_goTypes = []interface{}{
	(*ActiveNodeInfo)(nil), // 0: hadoop.hdfs.ActiveNodeInfo
}
var file_HAZKInfo_proto_depIdxs = []int32{
	0, // [0:0] is the sub-list for method output_type
	0, // [0:0] is the sub-list for method input_type
	0, // [0:0] is the sub-list for extension type_name
	0, // [0:0] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_HAZKInfo_proto_init() }
func file_HAZKInfo_proto_init() {
	if File_HAZKInfo_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_HAZKInfo_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*ActiveNodeInfo); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_HAZKInfo_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_HAZKInfo_proto_goTypes,
		DependencyIndexes: file_HAZKInfo_proto_depIdxs,
		MessageInfos:      file_HAZKInfo_proto_msgTypes,
	}.Build()
	File_HAZKInfo_proto = out.File
	file_HAZKInfo_proto_rawDesc = nil
	file_HAZKInfo_proto_goTypes = nil
	file_HAZKInfo_proto_depIdxs = nil
}
